# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionRaw.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10SessionRaw.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"q\n\nSessionRaw\x12\x37\n\x03raw\x18\x01 \x03(\x0b\x32*.AcFunDanmu.Im.Message.SessionRaw.RawEntry\x1a*\n\x08RawEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionRaw_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONRAW_RAWENTRY._options = None
  _SESSIONRAW_RAWENTRY._serialized_options = b'8\001'
  _SESSIONRAW._serialized_start=43
  _SESSIONRAW._serialized_end=156
  _SESSIONRAW_RAWENTRY._serialized_start=114
  _SESSIONRAW_RAWENTRY._serialized_end=156
# @@protoc_insertion_point(module_scope)
