# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMembersBriefInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bGroupMembersBriefInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"s\n\x15GroupMembersBriefInfo\x12\x13\n\x0bmemberCount\x18\x01 \x01(\x05\x12-\n\ntopMembers\x18\x02 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x16\n\x0elastUpdateTime\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMembersBriefInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBERSBRIEFINFO._serialized_start=72
  _GROUPMEMBERSBRIEFINFO._serialized_end=187
# @@protoc_insertion_point(module_scope)
