# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ForbiddenState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x46orbiddenState.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*S\n\x0e\x46orbiddenState\x12\x1b\n\x17UNKNOWN_FORBIDDEN_STATE\x10\x00\x12\x10\n\x0cUN_FORBIDDEN\x10\x01\x12\x12\n\x0e\x46ORBID_MESSAGE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ForbiddenState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FORBIDDENSTATE._serialized_start=53
  _FORBIDDENSTATE._serialized_end=136
# @@protoc_insertion_point(module_scope)
