# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallUserStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19VoiceCallUserStatus.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\x1a\nUser.proto\"\xf7\x02\n\x13VoiceCallUserStatus\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12R\n\x06status\x18\x02 \x01(\x0e\x32\x42.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallUserStatus.UserCallStatus\x12\x14\n\x0c\x61\x63\x63\x65ptTimeMs\x18\x03 \x01(\x03\x12<\n\tcallParam\x18\x04 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParam\"\x8e\x01\n\x0eUserCallStatus\x12\x0e\n\nUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0e\n\nREQUESTING\x10\x03\x12\x11\n\rNORMAL_CLOSED\x10\x04\x12\x12\n\x0eTIMEOUT_CLOSED\x10\x05\x12\x0b\n\x07\x42USYING\x10\x06\x12\x0c\n\x08\x46INISHED\x10\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallUserStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLUSERSTATUS._serialized_start=91
  _VOICECALLUSERSTATUS._serialized_end=466
  _VOICECALLUSERSTATUS_USERCALLSTATUS._serialized_start=324
  _VOICECALLUSERSTATUS_USERCALLSTATUS._serialized_end=466
# @@protoc_insertion_point(module_scope)
