# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderCreateResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionFolderInfo_pb2 as SessionFolderInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!SessionFolderCreateResponse.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x17SessionFolderInfo.proto\"n\n\x1bSessionFolderCreateResponse\x12O\n\x11sessionFolderInfo\x18\x01 \x01(\x0b\x32\x34.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderCreateResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERCREATERESPONSE._serialized_start=97
  _SESSIONFOLDERCREATERESPONSE._serialized_end=207
# @@protoc_insertion_point(module_scope)
