syntax = "proto3";

package AcFunDanmu.Im.Message;

import "ChatTarget.proto";
import "MessageReceiptInfo.proto";

message MessageReceiptRequest {
	repeated MessageReceiptInfo messageReceiptInfo = 1;
	ChatTarget chatTarget = 2;
}
