# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RelationEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13RelationEvent.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\"\xce\x01\n\rRelationEvent\x12[\n\x11relationEventType\x18\x01 \x01(\x0e\x32@.AcFunDanmu.Im.Cloud.Data.Update.RelationEvent.RelationEventType\x12\x0e\n\x06\x66romId\x18\x02 \x01(\x03\x12\x10\n\x08targetId\x18\x03 \x01(\x03\">\n\x11RelationEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x46OLLOWED\x10\x01\x12\x0e\n\nUNFOLLOWED\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RelationEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RELATIONEVENT._serialized_start=57
  _RELATIONEVENT._serialized_end=263
  _RELATIONEVENT_RELATIONEVENTTYPE._serialized_start=201
  _RELATIONEVENT_RELATIONEVENTTYPE._serialized_end=263
# @@protoc_insertion_point(module_scope)
