# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinRequestAckRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n GroupJoinRequestAckRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xa0\x02\n\x1aGroupJoinRequestAckRequest\x12\r\n\x05reqId\x18\x01 \x01(\x03\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12\x62\n\x10groupJoinAckType\x18\x03 \x01(\x0e\x32H.AcFunDanmu.Im.Cloud.Message.GroupJoinRequestAckRequest.GroupJoinAckType\x12\x14\n\x0c\x61uditComment\x18\x04 \x01(\t\x12\x1f\n\x17ignoreFutureJoinRequest\x18\x05 \x01(\x08\"G\n\x10GroupJoinAckType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05\x41GREE\x10\x01\x12\n\n\x06REFUSE\x10\x02\x12\n\n\x06IGNORE\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinRequestAckRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINREQUESTACKREQUEST._serialized_start=66
  _GROUPJOINREQUESTACKREQUEST._serialized_end=354
  _GROUPJOINREQUESTACKREQUEST_GROUPJOINACKTYPE._serialized_start=283
  _GROUPJOINREQUESTACKREQUEST_GROUPJOINACKTYPE._serialized_end=354
# @@protoc_insertion_point(module_scope)
