# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallAlreadyProcessedEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$VoiceCallAlreadyProcessedEvent.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\" \n\x1eVoiceCallAlreadyProcessedEventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallAlreadyProcessedEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLALREADYPROCESSEDEVENT._serialized_start=72
  _VOICECALLALREADYPROCESSEDEVENT._serialized_end=104
# @@protoc_insertion_point(module_scope)
