# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionMuteResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatSession_pb2 as ChatSession__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SessionMuteResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x11\x43hatSession.proto\"J\n\x13SessionMuteResponse\x12\x33\n\x07session\x18\x01 \x01(\x0b\x32\".AcFunDanmu.Im.Message.ChatSessionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionMuteResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONMUTERESPONSE._serialized_start=71
  _SESSIONMUTERESPONSE._serialized_end=145
# @@protoc_insertion_point(module_scope)
