# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RequsetBasicInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AppInfo_pb2 as AppInfo__pb2
import DeviceInfo_pb2 as DeviceInfo__pb2
import EnvInfo_pb2 as EnvInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16RequsetBasicInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\rAppInfo.proto\x1a\x10\x44\x65viceInfo.proto\x1a\rEnvInfo.proto\"\xf7\x02\n\x10RequsetBasicInfo\x12@\n\nclientType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.DeviceInfo.PlatformType\x12\x10\n\x08\x64\x65viceId\x18\x02 \x01(\t\x12\x10\n\x08\x63lientIp\x18\x03 \x01(\t\x12\x12\n\nappVersion\x18\x04 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x05 \x01(\t\x12-\n\x07\x61ppInfo\x18\x06 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.AppInfo\x12\x33\n\ndeviceInfo\x18\x07 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.DeviceInfo\x12-\n\x07\x65nvInfo\x18\x08 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.EnvInfo\x12\x12\n\nclientPort\x18\t \x01(\x05\x12\x10\n\x08location\x18\n \x01(\t\x12\x0b\n\x03kpf\x18\x0b \x01(\t\x12\x12\n\nclientIpV6\x18\x0c \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RequsetBasicInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REQUSETBASICINFO._serialized_start=96
  _REQUSETBASICINFO._serialized_end=471
# @@protoc_insertion_point(module_scope)
