# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: NoticeMetaType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14NoticeMetaType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\xaf\x01\n\x0eNoticeMetaType\x12\x1c\n\x18UNKNOWN_NOTICE_META_TYPE\x10\x00\x12\x1b\n\x17\x43OMMON_NOTICE_META_TYPE\x10\x01\x12\"\n\x1e\x43ONFIRM_INVITE_INTO_GROUP_META\x10\x02\x12 \n\x1c\x43ONFIRM_JOIN_INTO_GROUP_META\x10\x03\x12\x1c\n\x18LINKED_PROFILE_META_TYPE\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'NoticeMetaType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTICEMETATYPE._serialized_start=54
  _NOTICEMETATYPE._serialized_end=229
# @@protoc_insertion_point(module_scope)
