# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InvitationOperator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18InvitationOperator.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xdb\x01\n\x12InvitationOperator\x12+\n\x08operator\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12R\n\x0coperatorRole\x18\x02 \x01(\x0e\x32<.AcFunDanmu.Im.Cloud.Message.InvitationOperator.OperatorRole\"D\n\x0cOperatorRole\x12\x10\n\x0cUNKNOWN_ROLE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\x0b\n\x07MANAGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'InvitationOperator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INVITATIONOPERATOR._serialized_start=70
  _INVITATIONOPERATOR._serialized_end=289
  _INVITATIONOPERATOR_OPERATORROLE._serialized_start=221
  _INVITATIONOPERATOR_OPERATORROLE._serialized_end=289
# @@protoc_insertion_point(module_scope)
