# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMerchantSessionFolderCheckEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(B2CMerchantSessionFolderCheckEvent.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\nUser.proto\"\x8b\x01\n\"B2CMerchantSessionFolderCheckEvent\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08subBizId\x18\x02 \x01(\x05\x12\x12\n\nsyncOffset\x18\x03 \x01(\x03\x12\x16\n\x0elastUpdateTime\x18\x04 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMerchantSessionFolderCheckEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMERCHANTSESSIONFOLDERCHECKEVENT._serialized_start=92
  _B2CMERCHANTSESSIONFOLDERCHECKEVENT._serialized_end=231
# @@protoc_insertion_point(module_scope)
