# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtDrawGiftInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ZtDrawGiftInfo.proto\x12\nAcFunDanmu\"\xfa\x01\n\x0eZtDrawGiftInfo\x12\x13\n\x0bscreenWidth\x18\x01 \x01(\x03\x12\x14\n\x0cscreenHeight\x18\x02 \x01(\x03\x12\x39\n\tdrawPoint\x18\x03 \x03(\x0b\x32&.AcFunDanmu.ZtDrawGiftInfo.ZtDrawPoint\x1a\x81\x01\n\x0bZtDrawPoint\x12\x12\n\nmarginLeft\x18\x01 \x01(\x03\x12\x11\n\tmarginTop\x18\x02 \x01(\x03\x12\x12\n\nscaleRatio\x18\x03 \x01(\x01\x12\x0e\n\x06handup\x18\x04 \x01(\x08\x12\x12\n\npointWidth\x18\x05 \x01(\x03\x12\x13\n\x0bpointHeight\x18\x06 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtDrawGiftInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTDRAWGIFTINFO._serialized_start=37
  _ZTDRAWGIFTINFO._serialized_end=287
  _ZTDRAWGIFTINFO_ZTDRAWPOINT._serialized_start=158
  _ZTDRAWGIFTINFO_ZTDRAWPOINT._serialized_end=287
# @@protoc_insertion_point(module_scope)
