syntax = "proto3";

package AcFunDanmu.Im.Basic;

enum LinkErrorCode {
	SUCC = 0;
	BASIC_MIN = 10000;
	INTERNEL_ERROR = 10001;
	SERVICE_UNAVAILABLE = 10002;
	SERVICE_TIMEOUT = 10003;
	INVALID_TOKEN = 10004;
	REG_ENCYRPT_WITHOUT_TOKEN = 10005;
	PARSE_PB_HDR_FAIL = 10006;
	PARSE_PB_PLD_FAIL = 10007;
	PARSE_PB_FAIL = 10008;
	DECODED_LEN_FAIL = 10009;
	INVALID_KEY = 10010;
	ENCRYPT_FAIL = 10011;
	DECRYPT_FAIL = 10012;
	INVALID_TAG = 10013;
	INVALID_VER = 10014;
	INVALID_COMPRESS_TYPE = 10016;
	INVALID_ENCRYPT_TYPE = 10017;
	NOT_REGISTER = 10018;
	USER_NOT_ONLINE = 10019;
	INVALID_COMMAND = 10020;
	PUSH_UNREGISTER_ERROR = 10021;
	INVALID_SID = 10022;
	INVALID_INSTANCE_ID = 10023;
	CLIENT_LOCALE_NOT_MATCH = 10024;
	INVALID_TOKEN_PASSWORD_CHANGED = 10025;
	INVALID_TOKEN_TOKEN_EXPIRED = 10026;
	INVALID_TOKEN_TOKEN_VALUE_ERROR = 10027;
	INVALID_TOKEN_LOGIN_ON_OTHER_DEVICE = 10028;
	FORCE_RECONNECT = 10029;
	CLIENT_TIMEOUT = 10030;
	INVALID_ARGUMENT = 10031;
	INVALID_FORMAT_TOKEN = 10032;
	EMPTY_PAYLOAD = 10033;
	COMPRESS_FAIL = 10034;
	DECOMPRESS_FAIL = 10035;
	OUT_OF_ORDER = 10036;
	OUT_OF_LIMIT = 10037;
	TOO_LARGE_PAYLOAD = 10038;
	ANONYMOUSE_ERROR = 10039;
	BASIC_MAX = 19999;
}
