# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionSearchRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import TimeFilter_pb2 as TimeFilter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aSessionSearchRequest.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x10TimeFilter.proto\"\xc8\x01\n\x14SessionSearchRequest\x12\x11\n\tgroupName\x18\x01 \x03(\t\x12\x12\n\nmemberName\x18\x02 \x03(\t\x12\r\n\x05query\x18\x03 \x03(\t\x12\x10\n\x08\x66ileName\x18\x04 \x03(\t\x12:\n\ntimeFilter\x18\x05 \x01(\x0b\x32&.AcFunDanmu.Im.Cloud.Search.TimeFilter\x12\x1a\n\x12msgCountPerSession\x18\x06 \x01(\x05\x12\x10\n\x08memberId\x18\x07 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionSearchRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONSEARCHREQUEST._serialized_start=77
  _SESSIONSEARCHREQUEST._serialized_end=277
# @@protoc_insertion_point(module_scope)
