# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsEnterRoom.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveCsEnterRoom.proto\x12\nAcFunDanmu\"\x8b\x01\n\x11ZtLiveCsEnterRoom\x12\x10\n\x08isAuthor\x18\x01 \x01(\x08\x12\x16\n\x0ereconnectCount\x18\x02 \x01(\x05\x12\x15\n\rlastErrorCode\x18\x03 \x01(\x05\x12\x17\n\x0f\x65nterRoomAttach\x18\x04 \x01(\t\x12\x1c\n\x14\x63lientLiveSdkVersion\x18\x05 \x01(\t\"3\n\x14ZtLiveCsEnterRoomAck\x12\x1b\n\x13heartbeatIntervalMs\x18\x01 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsEnterRoom_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSENTERROOM._serialized_start=40
  _ZTLIVECSENTERROOM._serialized_end=179
  _ZTLIVECSENTERROOMACK._serialized_start=181
  _ZTLIVECSENTERROOMACK._serialized_end=232
# @@protoc_insertion_point(module_scope)
