# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderDataUpdate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionFolderBasic_pb2 as SessionFolderBasic__pb2
import SessionReferenceUpdateItem_pb2 as SessionReferenceUpdateItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dSessionFolderDataUpdate.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\x1a\x18SessionFolderBasic.proto\x1a SessionReferenceUpdateItem.proto\"\x8a\x02\n\x17SessionFolderDataUpdate\x12Q\n\x12sessionFolderBasic\x18\x01 \x03(\x0b\x32\x35.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderBasic\x12L\n\x05\x61\x64\x64\x65\x64\x18\x02 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItem\x12N\n\x07removed\x18\x03 \x03(\x0b\x32=.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceUpdateItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderDataUpdate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERDATAUPDATE._serialized_start=127
  _SESSIONFOLDERDATAUPDATE._serialized_end=393
# @@protoc_insertion_point(module_scope)
