syntax = "proto3";

package AcFunDanmu.Im.Cloud.Search;

import "Message.proto";

message GroupMsgSearchResult {
	string groupId = 1;
	int32 msgSize = 2;
	repeated Im.Message.Message msg = 3;
	string offset = 4;
	bool hasMore = 5;
}
