# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CSessionRemoveRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x42\x32\x43SessionRemoveRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x43hatTarget.proto\"\x81\x01\n\x17\x42\x32\x43SessionRemoveRequest\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\x12\n\ncategoryId\x18\x02 \x01(\x05\x12\x1b\n\x13notCleanAllMessages\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CSessionRemoveRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CSESSIONREMOVEREQUEST._serialized_start=75
  _B2CSESSIONREMOVEREQUEST._serialized_end=204
# @@protoc_insertion_point(module_scope)
