# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccountType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x41\x63\x63ountType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*A\n\x0b\x41\x63\x63ountType\x12\n\n\x06UNKNOW\x10\x00\x12\x0c\n\x08OFFICIAL\x10\x01\x12\n\n\x06NORMAL\x10\x02\x12\x0c\n\x08STRANGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccountType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCOUNTTYPE._serialized_start=44
  _ACCOUNTTYPE._serialized_end=109
# @@protoc_insertion_point(module_scope)
