# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KsImDataUpdatePushPayload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import KsImDataUpdateType_pb2 as KsImDataUpdateType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fKsImDataUpdatePushPayload.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\x1a\x18KsImDataUpdateType.proto\"\x82\x01\n\x19KsImDataUpdatePushPayload\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32\x33.AcFunDanmu.Im.Cloud.Data.Update.KsImDataUpdateType\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KsImDataUpdatePushPayload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KSIMDATAUPDATEPUSHPAYLOAD._serialized_start=95
  _KSIMDATAUPDATEPUSHPAYLOAD._serialized_end=225
# @@protoc_insertion_point(module_scope)
