# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushServiceToken.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16PushServiceToken.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xc0\x02\n\x10PushServiceToken\x12@\n\x08pushType\x18\x01 \x01(\x0e\x32..AcFunDanmu.Im.Basic.PushServiceToken.PushType\x12\r\n\x05token\x18\x02 \x01(\x0c\x12\x15\n\risPassThrough\x18\x03 \x01(\x08\"\xc3\x01\n\x08PushType\x12\x14\n\x10kPushTypeInvalid\x10\x00\x12\x11\n\rkPushTypeAPNS\x10\x01\x12\x13\n\x0fkPushTypeXmPush\x10\x02\x12\x13\n\x0fkPushTypeJgPush\x10\x03\x12\x13\n\x0fkPushTypeGtPush\x10\x04\x12\x13\n\x0fkPushTypeOpPush\x10\x05\x12\x13\n\x0fkPushTypeVvPush\x10\x06\x12\x13\n\x0fkPushTypeHwPush\x10\x07\x12\x10\n\x0ckPushTypeFcm\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PushServiceToken_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUSHSERVICETOKEN._serialized_start=48
  _PUSHSERVICETOKEN._serialized_end=368
  _PUSHSERVICETOKEN_PUSHTYPE._serialized_start=173
  _PUSHSERVICETOKEN_PUSHTYPE._serialized_end=368
# @@protoc_insertion_point(module_scope)
