syntax = "proto3";

package AcFunDanmu.Im.Basic;

import "AccessPointsConfig.proto";

message KeepAliveResponse {
	AccessPointsConfig accessPointsConfig = 1;
	int64 serverMsec = 2;
	AccessPointsConfig accessPointsConfigIpv6 = 3;
	AccessPointsConfig accessPointsConfigQuic = 6;
	AccessPointsConfig accessPointsConfigQuicIpv6 = 7;
	AccessPointsConfig accessPointsConfigWs = 8;
}
