syntax = "proto3";

package AcFunDanmu.Im.Cloud.SessionFolder;

import "SessionReference.proto";

message SessionFolderBatchDeleteRefRequest {
	SessionReference sessionReference = 1;
	repeated string targetSessionFolderId = 2;
}
