# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinReqListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupJoinReq_pb2 as GroupJoinReq__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eGroupJoinReqListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x12GroupJoinReq.proto\"k\n\x18GroupJoinReqListResponse\x12?\n\x0cgroupJoinReq\x18\x01 \x03(\x0b\x32).AcFunDanmu.Im.Cloud.Message.GroupJoinReq\x12\x0e\n\x06offset\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinReqListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINREQLISTRESPONSE._serialized_start=83
  _GROUPJOINREQLISTRESPONSE._serialized_end=190
# @@protoc_insertion_point(module_scope)
