# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalCurrentRedpackList.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)CommonStateSignalCurrentRedpackList.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xe4\x03\n#CommonStateSignalCurrentRedpackList\x12I\n\x08redpacks\x18\x01 \x03(\x0b\x32\x37.AcFunDanmu.CommonStateSignalCurrentRedpackList.Redpack\x1a\xaf\x02\n\x07Redpack\x12*\n\x06sender\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12[\n\rdisplayStatus\x18\x02 \x01(\x0e\x32\x44.AcFunDanmu.CommonStateSignalCurrentRedpackList.RedpackDisplayStatus\x12\x17\n\x0fgrabBeginTimeMs\x18\x03 \x01(\x03\x12\x1c\n\x14getTokenLatestTimeMs\x18\x04 \x01(\x03\x12\x11\n\tredPackId\x18\x05 \x01(\t\x12\x16\n\x0eredpackBizUnit\x18\x06 \x01(\t\x12\x15\n\rredpackAmount\x18\x07 \x01(\x03\x12\x17\n\x0fsettleBeginTime\x18\x08 \x01(\x03\x12\t\n\x01i\x18\t \x01(\x03\"@\n\x14RedpackDisplayStatus\x12\x08\n\x04SHOW\x10\x00\x12\r\n\tGET_TOKEN\x10\x01\x12\x08\n\x04GRAB\x10\x02\x12\x05\n\x01\x65\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalCurrentRedpackList_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCURRENTREDPACKLIST._serialized_start=80
  _COMMONSTATESIGNALCURRENTREDPACKLIST._serialized_end=564
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACK._serialized_start=195
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACK._serialized_end=498
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACKDISPLAYSTATUS._serialized_start=500
  _COMMONSTATESIGNALCURRENTREDPACKLIST_REDPACKDISPLAYSTATUS._serialized_end=564
# @@protoc_insertion_point(module_scope)
