# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatTargetType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x43hatTargetType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*\xa7\x01\n\x0e\x43hatTargetType\x12\x0c\n\x08\x43TT_USER\x10\x00\x12\x11\n\rCTT_CHAT_ROOM\x10\x02\x12\x19\n\x15\x43TT_MULTI_PLAYER_ROOM\x10\x03\x12\r\n\tCTT_GROUP\x10\x04\x12\x0f\n\x0b\x43TT_CHANNEL\x10\x05\x12\x11\n\rCTT_AGGREGATE\x10\x06\x12\x0b\n\x07\x43TT_B2C\x10\x07\x12\x19\n\x15\x43TT_SUB_BIZ_AGGREGATE\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatTargetType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATTARGETTYPE._serialized_start=48
  _CHATTARGETTYPE._serialized_end=215
# @@protoc_insertion_point(module_scope)
