# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalPkStatistic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PkAudienceContributionInfo_pb2 as PkAudienceContributionInfo__pb2
import PkPlayerStatistic_pb2 as PkPlayerStatistic__pb2
import PkRoundInfo_pb2 as PkRoundInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"CommonStateSignalPkStatistic.proto\x12\nAcFunDanmu\x1a PkAudienceContributionInfo.proto\x1a\x17PkPlayerStatistic.proto\x1a\x11PkRoundInfo.proto\"\x82\x02\n\x1c\x43ommonStateSignalPkStatistic\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x03\x12\t\n\x01\x63\x18\x03 \x01(\x03\x12\t\n\x01\x64\x18\x04 \x01(\x03\x12\t\n\x01\x65\x18\x05 \x01(\x08\x12\t\n\x01\x66\x18\x06 \x01(\x03\x12\t\n\x01g\x18\x07 \x01(\x03\x12\t\n\x01h\x18\x08 \x01(\x03\x12\x31\n\x01i\x18\t \x03(\x0b\x32&.AcFunDanmu.PkAudienceContributionInfo\x12(\n\x01j\x18\n \x03(\x0b\x32\x1d.AcFunDanmu.PkPlayerStatistic\x12\"\n\x01k\x18\x0b \x01(\x0b\x32\x17.AcFunDanmu.PkRoundInfo\x12\t\n\x01l\x18\x0c \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalPkStatistic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALPKSTATISTIC._serialized_start=129
  _COMMONSTATESIGNALPKSTATISTIC._serialized_end=387
# @@protoc_insertion_point(module_scope)
