# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupExtraDataUpdate_pb2 as GroupExtraDataUpdate__pb2
import GroupHeadUrlUpdate_pb2 as GroupHeadUrlUpdate__pb2
import GroupInviteNeedUserAgree_pb2 as GroupInviteNeedUserAgree__pb2
import GroupSettingAdminTransfer_pb2 as GroupSettingAdminTransfer__pb2
import GroupSettingBatchUpdate_pb2 as GroupSettingBatchUpdate__pb2
import GroupSettingDesc_pb2 as GroupSettingDesc__pb2
import GroupSettingInvitePermission_pb2 as GroupSettingInvitePermission__pb2
import GroupSettingJoinNeedPermission_pb2 as GroupSettingJoinNeedPermission__pb2
import GroupSettingMemberSilence_pb2 as GroupSettingMemberSilence__pb2
import GroupSettingMemberTempSilence_pb2 as GroupSettingMemberTempSilence__pb2
import GroupSettingRemindAllOnlyAdmin_pb2 as GroupSettingRemindAllOnlyAdmin__pb2
import GroupSettingRename_pb2 as GroupSettingRename__pb2
import GroupSettingUpdateOnlyAdmin_pb2 as GroupSettingUpdateOnlyAdmin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19GroupSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1aGroupExtraDataUpdate.proto\x1a\x18GroupHeadUrlUpdate.proto\x1a\x1eGroupInviteNeedUserAgree.proto\x1a\x1fGroupSettingAdminTransfer.proto\x1a\x1dGroupSettingBatchUpdate.proto\x1a\x16GroupSettingDesc.proto\x1a\"GroupSettingInvitePermission.proto\x1a$GroupSettingJoinNeedPermission.proto\x1a\x1fGroupSettingMemberSilence.proto\x1a#GroupSettingMemberTempSilence.proto\x1a$GroupSettingRemindAllOnlyAdmin.proto\x1a\x18GroupSettingRename.proto\x1a!GroupSettingUpdateOnlyAdmin.proto\"\xf6\x08\n\x13GroupSettingRequest\x12\x41\n\x06rename\x18\x02 \x01(\x0b\x32/.AcFunDanmu.Im.Cloud.Message.GroupSettingRenameH\x00\x12=\n\x04\x64\x65sc\x18\x03 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Message.GroupSettingDescH\x00\x12Y\n\x12joinNeedPermission\x18\x04 \x01(\x0b\x32;.AcFunDanmu.Im.Cloud.Message.GroupSettingJoinNeedPermissionH\x00\x12U\n\x10invitePermission\x18\x05 \x01(\x0b\x32\x39.AcFunDanmu.Im.Cloud.Message.GroupSettingInvitePermissionH\x00\x12U\n\x13groupMembersSilence\x18\x06 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Message.GroupSettingMemberSilenceH\x00\x12T\n\x12groupAdminTransfer\x18\x07 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Message.GroupSettingAdminTransferH\x00\x12Z\n\x16settingUpdateOnlyAdmin\x18\x08 \x01(\x0b\x32\x38.AcFunDanmu.Im.Cloud.Message.GroupSettingUpdateOnlyAdminH\x00\x12Y\n\x12remindAllOnlyAdmin\x18\t \x01(\x0b\x32;.AcFunDanmu.Im.Cloud.Message.GroupSettingRemindAllOnlyAdminH\x00\x12K\n\x0b\x62\x61tchUpdate\x18\n \x01(\x0b\x32\x34.AcFunDanmu.Im.Cloud.Message.GroupSettingBatchUpdateH\x00\x12\\\n\x16groupMemberTempSilence\x18\x0b \x01(\x0b\x32:.AcFunDanmu.Im.Cloud.Message.GroupSettingMemberTempSilenceH\x00\x12Q\n\x14groupExtraDataUpdate\x18\x0c \x01(\x0b\x32\x31.AcFunDanmu.Im.Cloud.Message.GroupExtraDataUpdateH\x00\x12M\n\x12groupHeadUrlUpdate\x18\r \x01(\x0b\x32/.AcFunDanmu.Im.Cloud.Message.GroupHeadUrlUpdateH\x00\x12Y\n\x18groupInviteNeedUserAgree\x18\x0e \x01(\x0b\x32\x35.AcFunDanmu.Im.Cloud.Message.GroupInviteNeedUserAgreeH\x00\x12\x0f\n\x07groupId\x18\x01 \x01(\tB\x0e\n\x0cGroupSettingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPSETTINGREQUEST._serialized_start=476
  _GROUPSETTINGREQUEST._serialized_end=1618
# @@protoc_insertion_point(module_scope)
