syntax = "proto3";

package AcFunDanmu;

import "ZtLiveUserInfo.proto";

message CommonStateSignalTopUsers {
	repeated TopUser user = 1; // topUser

	message TopUser {
		ZtLiveUserInfo userInfo = 1;
		string customWatchingListData = 3;
		string displaySendAmount = 4;
		bool anonymousUser = 5;
	}
}
