# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderAddRefResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionReference_pb2 as SessionReference__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!SessionFolderAddRefResponse.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x16SessionReference.proto\"l\n\x1bSessionFolderAddRefResponse\x12M\n\x10sessionReference\x18\x01 \x03(\x0b\x32\x33.AcFunDanmu.Im.Cloud.SessionFolder.SessionReferenceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderAddRefResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERADDREFRESPONSE._serialized_start=96
  _SESSIONFOLDERADDREFRESPONSE._serialized_end=204
# @@protoc_insertion_point(module_scope)
