# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserGroupInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupInfo_pb2 as GroupInfo__pb2
import GroupMember_pb2 as GroupMember__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13UserGroupInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0fGroupInfo.proto\x1a\x11GroupMember.proto\"\x89\x01\n\rUserGroupInfo\x12\x39\n\tgroupInfo\x18\x01 \x01(\x0b\x32&.AcFunDanmu.Im.Cloud.Message.GroupInfo\x12=\n\x0bgroupMember\x18\x02 \x01(\x0b\x32(.AcFunDanmu.Im.Cloud.Message.GroupMemberb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserGroupInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERGROUPINFO._serialized_start=89
  _USERGROUPINFO._serialized_end=226
# @@protoc_insertion_point(module_scope)
