# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsQuestionMessageContent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x43sQuestionMessageContent.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xf4\x02\n\x18\x43sQuestionMessageContent\x12\r\n\x05title\x18\x01 \x01(\t\x12R\n\x08question\x18\x02 \x03(\x0b\x32@.AcFunDanmu.Im.Cloud.Message.CsQuestionMessageContent.CsQuestion\x12\x12\n\nbizContent\x18\x03 \x01(\x0c\x1a\xe0\x01\n\nCsQuestion\x12\x12\n\nquestionId\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\tactionUrl\x18\x03 \x01(\t\x12_\n\nactionType\x18\x04 \x01(\x0e\x32K.AcFunDanmu.Im.Cloud.Message.CsQuestionMessageContent.CsQuestion.ActionType\"<\n\nActionType\x12\x0e\n\nAT_UNKNOWN\x10\x00\x12\x0c\n\x08REDIRECT\x10\x01\x12\x10\n\x0cSEND_MESSAGE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsQuestionMessageContent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSQUESTIONMESSAGECONTENT._serialized_start=64
  _CSQUESTIONMESSAGECONTENT._serialized_end=436
  _CSQUESTIONMESSAGECONTENT_CSQUESTION._serialized_start=212
  _CSQUESTIONMESSAGECONTENT_CSQUESTION._serialized_end=436
  _CSQUESTIONMESSAGECONTENT_CSQUESTION_ACTIONTYPE._serialized_start=376
  _CSQUESTIONMESSAGECONTENT_CSQUESTION_ACTIONTYPE._serialized_end=436
# @@protoc_insertion_point(module_scope)
