syntax = "proto3";

package AcFunDanmu;

import "AuthorChatPlayerInfo.proto";

message CommonStateSignalAuthorChatCall {
	string authorChatId = 1;
	AuthorChatPlayerInfo inviterUserInfo = 2;
	int64 callTimestampMs = 3;
}
