# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupFindType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13GroupFindType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\xa6\x01\n\rGroupFindType\x12\x0e\n\nBY_UNKNOWN\x10\x00\x12\t\n\x05\x42Y_ID\x10\x01\x12\x0b\n\x07\x42Y_NAME\x10\x02\x12\x0e\n\nBY_QR_CODE\x10\x03\x12\x0b\n\x07\x42Y_CARD\x10\x04\x12\x11\n\rBY_INVITATION\x10\x05\x12\x11\n\rBY_SHARE_LINK\x10\x06\x12\x0e\n\nBY_PROFILE\x10\x07\x12\r\n\tBY_SEARCH\x10\x08\x12\x0b\n\x07\x42Y_NEWS\x10\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupFindType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPFINDTYPE._serialized_start=53
  _GROUPFINDTYPE._serialized_end=219
# @@protoc_insertion_point(module_scope)
