syntax = "proto3";

package AcFunDanmu;

message CommonNotifySignalRemoveApplyUser {
    int64 a = 1;
    unknown b = 2;

    enum unknown {
        c = 0;
        d = 1;
        e = 2;
        f = 3;
    }
}
