# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalWishSheetCurrentState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,CommonStateSignalWishSheetCurrentState.proto\x12\nAcFunDanmu\"\xd9\x01\n&CommonStateSignalWishSheetCurrentState\x12\t\n\x01\x61\x18\x01 \x01(\t\x12N\n\x01\x62\x18\x02 \x03(\x0b\x32\x43.AcFunDanmu.CommonStateSignalWishSheetCurrentState.WishCurrentState\x1aT\n\x10WishCurrentState\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x03\x12\t\n\x01\x63\x18\x03 \x01(\x03\x12\t\n\x01\x64\x18\x04 \x01(\x03\x12\t\n\x01\x65\x18\x05 \x01(\t\x12\t\n\x01\x66\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalWishSheetCurrentState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE._serialized_start=61
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE._serialized_end=278
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE_WISHCURRENTSTATE._serialized_start=194
  _COMMONSTATESIGNALWISHSHEETCURRENTSTATE_WISHCURRENTSTATE._serialized_end=278
# @@protoc_insertion_point(module_scope)
