# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserLoginDeviceInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19UserLoginDeviceInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Profile\"s\n\x13UserLoginDeviceInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x0b\n\x03kpf\x18\x03 \x01(\t\x12\x16\n\x0elastOnlineTime\x18\x04 \x01(\x03\x12\x11\n\tbizStatus\x18\x05 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserLoginDeviceInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERLOGINDEVICEINFO._serialized_start=58
  _USERLOGINDEVICEINFO._serialized_end=173
# @@protoc_insertion_point(module_scope)
