# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Reminder_pb2 as Reminder__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x0eReminder.proto\x1a\nUser.proto\"\xd8\x05\n\x07Message\x12\r\n\x05seqId\x18\x01 \x01(\x03\x12\x13\n\x0b\x63lientSeqId\x18\x02 \x01(\x03\x12\x13\n\x0btimestampMs\x18\x03 \x01(\x03\x12+\n\x08\x66romUser\x18\x04 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08targetId\x18\x05 \x01(\x03\x12)\n\x06toUser\x18\x06 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\r\n\x05title\x18\x07 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x08 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\t \x01(\x0c\x12\x12\n\nbackupTips\x18\n \x01(\t\x12,\n\treceivers\x18\x0b \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x16\n\x0enotCountUnread\x18\x0c \x01(\x08\x12\x17\n\x0fsessionPriority\x18\r \x01(\x05\x12\x19\n\x11sessionCategoryId\x18\x0e \x01(\x05\x12\x1a\n\x12sessionAccountType\x18\x0f \x01(\x05\x12\x1c\n\x14notAutoCreateSession\x18\x10 \x01(\x08\x12\x18\n\x10userRelationship\x18\x11 \x01(\x05\x12\x13\n\x0bstrTargetId\x18\x12 \x01(\t\x12\x33\n\x10\x65xcludeReceivers\x18\x13 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x12\n\nmarkDelete\x18\x14 \x01(\x08\x12\x31\n\x08reminder\x18\x15 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Message.Reminder\x12\r\n\x05\x65xtra\x18\x16 \x01(\x0c\x12\x17\n\x0freceiptRequired\x18\x17 \x01(\x08\x12/\n\x0crealFromUser\x18\x18 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x0f\n\x07\x63sExtra\x18\x19 \x01(\x0c\x12\x18\n\x10sessionInvisible\x18\x1a \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=69
  _MESSAGE._serialized_end=797
# @@protoc_insertion_point(module_scope)
