# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalRecentComment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CommonActionSignalComment_pb2 as CommonActionSignalComment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$CommonStateSignalRecentComment.proto\x12\nAcFunDanmu\x1a\x1f\x43ommonActionSignalComment.proto\"X\n\x1e\x43ommonStateSignalRecentComment\x12\x36\n\x07\x63omment\x18\x01 \x03(\x0b\x32%.AcFunDanmu.CommonActionSignalCommentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalRecentComment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALRECENTCOMMENT._serialized_start=85
  _COMMONSTATESIGNALRECENTCOMMENT._serialized_end=173
# @@protoc_insertion_point(module_scope)
