# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveScMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15ZtLiveScMessage.proto\x12\nAcFunDanmu\"\xec\x01\n\x0fZtLiveScMessage\x12\x13\n\x0bmessageType\x18\x01 \x01(\t\x12\x44\n\x0f\x63ompressionType\x18\x02 \x01(\x0e\x32+.AcFunDanmu.ZtLiveScMessage.CompressionType\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0e\n\x06liveId\x18\x04 \x01(\t\x12\x0e\n\x06ticket\x18\x05 \x01(\t\x12\x19\n\x11serverTimestampMs\x18\x06 \x01(\x03\"2\n\x0f\x43ompressionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04GZIP\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveScMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESCMESSAGE._serialized_start=38
  _ZTLIVESCMESSAGE._serialized_end=274
  _ZTLIVESCMESSAGE_COMPRESSIONTYPE._serialized_start=224
  _ZTLIVESCMESSAGE_COMPRESSIONTYPE._serialized_end=274
# @@protoc_insertion_point(module_scope)
