# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ErrorMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import LocaleMessage_pb2 as LocaleMessage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x45rrorMessage.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x13LocaleMessage.proto\"J\n\x0c\x45rrorMessage\x12:\n\x0elocaleMessages\x18\x01 \x03(\x0b\x32\".AcFunDanmu.Im.Basic.LocaleMessageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ErrorMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ERRORMESSAGE._serialized_start=64
  _ERRORMESSAGE._serialized_end=138
# @@protoc_insertion_point(module_scope)
