# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalRichText.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2
import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CommonActionSignalRichText.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\x1a\x12ImageCdnNode.proto\"\xef\x04\n\x1a\x43ommonActionSignalRichText\x12H\n\x08segments\x18\x01 \x03(\x0b\x32\x36.AcFunDanmu.CommonActionSignalRichText.RichTextSegment\x12\x12\n\nsendTimeMs\x18\x02 \x01(\x03\x1ax\n\x0cImageSegment\x12*\n\x08pictures\x18\x01 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\x17\n\x0f\x61lternativeText\x18\x02 \x01(\t\x12\x18\n\x10\x61lternativeColor\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\x1a\x36\n\x0cPlainSegment\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x1a\xf4\x01\n\x0fRichTextSegment\x12J\n\x08userInfo\x18\x01 \x01(\x0b\x32\x36.AcFunDanmu.CommonActionSignalRichText.UserInfoSegmentH\x00\x12\x44\n\x05plain\x18\x02 \x01(\x0b\x32\x33.AcFunDanmu.CommonActionSignalRichText.PlainSegmentH\x00\x12\x44\n\x05image\x18\x03 \x01(\x0b\x32\x33.AcFunDanmu.CommonActionSignalRichText.ImageSegmentH\x00\x42\t\n\x07segment\x1aJ\n\x0fUserInfoSegment\x12(\n\x04user\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\r\n\x05\x63olor\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalRichText_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALRICHTEXT._serialized_start=91
  _COMMONACTIONSIGNALRICHTEXT._serialized_end=714
  _COMMONACTIONSIGNALRICHTEXT_IMAGESEGMENT._serialized_start=215
  _COMMONACTIONSIGNALRICHTEXT_IMAGESEGMENT._serialized_end=335
  _COMMONACTIONSIGNALRICHTEXT_PLAINSEGMENT._serialized_start=337
  _COMMONACTIONSIGNALRICHTEXT_PLAINSEGMENT._serialized_end=391
  _COMMONACTIONSIGNALRICHTEXT_RICHTEXTSEGMENT._serialized_start=394
  _COMMONACTIONSIGNALRICHTEXT_RICHTEXTSEGMENT._serialized_end=638
  _COMMONACTIONSIGNALRICHTEXT_USERINFOSEGMENT._serialized_start=640
  _COMMONACTIONSIGNALRICHTEXT_USERINFOSEGMENT._serialized_end=714
# @@protoc_insertion_point(module_scope)
