syntax = "proto3";

package AcFunDanmu;

import "ImageCdnNode.proto";

message BackgroundStyle {
    string a = 1;
    repeated ImageCdnNode b = 2;

    enum unknown {
        c = 0;
        d = 1;
        e = 2;
    }
}
