syntax = "proto3";

package AcFunDanmu;

import "ImageCdnNode.proto";
import "ZtLiveUserIdentity.proto";

message ZtLiveUserInfo {
	int64 userId = 1;
	string nickname = 2;
	repeated ImageCdnNode avatar = 3;
	string badge = 4;  // bizCustomInfo
    ZtLiveUserIdentity userIdentity = 5;
	bool f = 6;
	string g = 7;
}
