# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PullNewResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15PullNewResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\rMessage.proto\"C\n\x0fPullNewResponse\x12\x30\n\x08messages\x18\x01 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Messageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PullNewResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PULLNEWRESPONSE._serialized_start=63
  _PULLNEWRESPONSE._serialized_end=130
# @@protoc_insertion_point(module_scope)
