syntax = "proto3";

package AcFunDanmu;

message CommonNotifySignalCoverAuditResult {
	AuditStatus auditStatus = 1;

	enum AuditStatus {
		SUCCESS = 0;
		COVER_AUDIT_FAILED = 1;
		CAPTION_AUDIT_FAILED = 2;
		BOTH_FAILED = 3;
	}
}
