# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInviteResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupMember_pb2 as GroupMember__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19GroupInviteResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x11GroupMember.proto\"\xf1\x01\n\x13GroupInviteResponse\x12\x0f\n\x07groupId\x18\x01 \x01(\t\x12S\n\x0cinviteStatus\x18\x02 \x01(\x0e\x32=.AcFunDanmu.Im.Cloud.Message.GroupInviteResponse.InviteStatus\x12\x39\n\x07members\x18\x03 \x03(\x0b\x32(.AcFunDanmu.Im.Cloud.Message.GroupMember\"9\n\x0cInviteStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04SUCC\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInviteResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINVITERESPONSE._serialized_start=78
  _GROUPINVITERESPONSE._serialized_end=319
  _GROUPINVITERESPONSE_INVITESTATUS._serialized_start=262
  _GROUPINVITERESPONSE_INVITESTATUS._serialized_end=319
# @@protoc_insertion_point(module_scope)
