# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageBatchSendResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SendMessageResponse_pb2 as SendMessageResponse__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eMessageBatchSendResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x19SendMessageResponse.proto\"X\n\x18MessageBatchSendResponse\x12<\n\x08response\x18\x01 \x03(\x0b\x32*.AcFunDanmu.Im.Message.SendMessageResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageBatchSendResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGEBATCHSENDRESPONSE._serialized_start=84
  _MESSAGEBATCHSENDRESPONSE._serialized_end=172
# @@protoc_insertion_point(module_scope)
