# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ManagerSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bManagerSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xdb\x01\n\x15ManagerSettingRequest\x12*\n\x07manager\x18\x01 \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12O\n\toperation\x18\x02 \x01(\x0e\x32<.AcFunDanmu.Im.Cloud.Message.ManagerSettingRequest.Operation\x12\x0f\n\x07groupId\x18\x03 \x01(\t\"4\n\tOperation\x12\x15\n\x11UNKNOWN_OPERATION\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\x07\n\x03\x44\x45L\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ManagerSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MANAGERSETTINGREQUEST._serialized_start=73
  _MANAGERSETTINGREQUEST._serialized_end=292
  _MANAGERSETTINGREQUEST_OPERATION._serialized_start=240
  _MANAGERSETTINGREQUEST_OPERATION._serialized_end=292
# @@protoc_insertion_point(module_scope)
