# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsCmd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11ZtLiveCsCmd.proto\x12\nAcFunDanmu\"O\n\x0bZtLiveCsCmd\x12\x0f\n\x07\x63mdType\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x0e\n\x06ticket\x18\x03 \x01(\t\x12\x0e\n\x06liveId\x18\x04 \x01(\t\"Z\n\x0eZtLiveCsCmdAck\x12\x12\n\ncmdAckType\x18\x01 \x01(\t\x12\x11\n\terrorCode\x18\x02 \x01(\x03\x12\x10\n\x08\x65rrorMsg\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsCmd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSCMD._serialized_start=33
  _ZTLIVECSCMD._serialized_end=112
  _ZTLIVECSCMDACK._serialized_start=114
  _ZTLIVECSCMDACK._serialized_end=204
# @@protoc_insertion_point(module_scope)
