# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DownstreamPayload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x44ownstreamPayload.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa5\x01\n\x11\x44ownstreamPayload\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\r\n\x05seqId\x18\x02 \x01(\x03\x12\x11\n\terrorCode\x18\x03 \x01(\x05\x12\x13\n\x0bpayloadData\x18\x04 \x01(\x0c\x12\x10\n\x08\x65rrorMsg\x18\x05 \x01(\t\x12\x11\n\terrorData\x18\x06 \x01(\x0c\x12\x0e\n\x06subBiz\x18\x07 \x01(\t\x12\x13\n\x0bklinkPushId\x18\x08 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DownstreamPayload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOWNSTREAMPAYLOAD._serialized_start=49
  _DOWNSTREAMPAYLOAD._serialized_end=214
# @@protoc_insertion_point(module_scope)
