# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveUserIdentity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ZtLiveUserIdentity.proto\x12\nAcFunDanmu\"\x8a\x01\n\x12ZtLiveUserIdentity\x12?\n\x0bmanagerType\x18\x01 \x01(\x0e\x32*.AcFunDanmu.ZtLiveUserIdentity.ManagerType\"3\n\x0bManagerType\x12\x18\n\x14UNKNOWN_MANAGER_TYPE\x10\x00\x12\n\n\x06NORMAL\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveUserIdentity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEUSERIDENTITY._serialized_start=41
  _ZTLIVEUSERIDENTITY._serialized_end=179
  _ZTLIVEUSERIDENTITY_MANAGERTYPE._serialized_start=128
  _ZTLIVEUSERIDENTITY_MANAGERTYPE._serialized_end=179
# @@protoc_insertion_point(module_scope)
