# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageStatusSettingListRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import MessageReceiveStatus_pb2 as MessageReceiveStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%MessageStatusSettingListRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x1aMessageReceiveStatus.proto\"}\n\x1fMessageStatusSettingListRequest\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.AcFunDanmu.Im.Message.MessageReceiveStatus\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageStatusSettingListRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGESTATUSSETTINGLISTREQUEST._serialized_start=92
  _MESSAGESTATUSSETTINGLISTREQUEST._serialized_end=217
# @@protoc_insertion_point(module_scope)
