# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccessPointsConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AccessPoint_pb2 as AccessPoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x41\x63\x63\x65ssPointsConfig.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x11\x41\x63\x63\x65ssPoint.proto\"\xd7\x01\n\x12\x41\x63\x63\x65ssPointsConfig\x12\x34\n\noptimalAps\x18\x01 \x03(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPoint\x12\x33\n\tbackupAps\x18\x02 \x03(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPoint\x12\x16\n\x0e\x61vailablePorts\x18\x03 \x03(\r\x12>\n\x14\x66orceLastConnectedAp\x18\x04 \x01(\x0b\x32 .AcFunDanmu.Im.Basic.AccessPointb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccessPointsConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINTSCONFIG._serialized_start=69
  _ACCESSPOINTSCONFIG._serialized_end=284
# @@protoc_insertion_point(module_scope)
