# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsAckErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x43sAckErrorCode.proto\x12\nAcFunDanmu*\xda\x01\n\x0e\x43sAckErrorCode\x12\x12\n\x0eSUCCESS_CS_ACK\x10\x00\x12\x0f\n\x0bLIVE_CLOSED\x10\x01\x12\x12\n\x0eTICKET_ILLEGAL\x10\x02\x12\x12\n\x0e\x41TTACH_ILLEGAL\x10\x03\x12\x14\n\x10USER_NOT_IN_ROOM\x10\x04\x12\x10\n\x0cSERVER_ERROR\x10\x05\x12\x19\n\x15REQUEST_PARAM_INVALID\x10\x06\x12#\n\x1fROOM_NOT_EXIST_IN_STATE_MANAGER\x10\x07\x12\x13\n\x0fNEW_LIVE_OPENED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsAckErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSACKERRORCODE._serialized_start=37
  _CSACKERRORCODE._serialized_end=255
# @@protoc_insertion_point(module_scope)
