# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProfileUserLoginDeviceInfoListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import UserLoginDeviceInfo_pb2 as UserLoginDeviceInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ProfileUserLoginDeviceInfoListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Profile\x1a\x19UserLoginDeviceInfo.proto\"w\n&ProfileUserLoginDeviceInfoListResponse\x12M\n\x13userLoginDeviceInfo\x18\x01 \x03(\x0b\x32\x30.AcFunDanmu.Im.Cloud.Profile.UserLoginDeviceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ProfileUserLoginDeviceInfoListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILEUSERLOGINDEVICEINFOLISTRESPONSE._serialized_start=104
  _PROFILEUSERLOGINDEVICEINFOLISTRESPONSE._serialized_end=223
# @@protoc_insertion_point(module_scope)
