# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallRequestEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallType_pb2 as CallType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bVoiceCallRequestEvent.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0e\x43\x61llType.proto\"S\n\x15VoiceCallRequestEvent\x12:\n\x08\x63\x61llType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallRequestEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLREQUESTEVENT._serialized_start=79
  _VOICECALLREQUESTEVENT._serialized_end=162
# @@protoc_insertion_point(module_scope)
