syntax = "proto3";

package AcFunDanmu;

message CommonStateSignalAuthorChatChangeSoundConfig {
	string authorChatId = 1;
	SoundConfigChangeType soundConfigChangeType = 2; // authorChatVoiceType

	enum SoundConfigChangeType {
		UNKNOWN = 0;
		OPEN_SOUND = 1;
		CLOSE_SOUND = 2;
	}
}
