# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserActionInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2
import UserAction_pb2 as UserAction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14UserActionInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Channel\x1a\nUser.proto\x1a\x10UserAction.proto\"\x85\x01\n\x0eUserActionInfo\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x37\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\'.AcFunDanmu.Im.Cloud.Channel.UserAction\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserActionInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERACTIONINFO._serialized_start=84
  _USERACTIONINFO._serialized_end=217
# @@protoc_insertion_point(module_scope)
