# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LiveFeatureState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16LiveFeatureState.proto\x12\nAcFunDanmu\"\x9d\x02\n\x10LiveFeatureState\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.AcFunDanmu.LiveFeatureState.FeatureType\x12\x38\n\x05state\x18\x02 \x01(\x0e\x32).AcFunDanmu.LiveFeatureState.FeatureState\"9\n\x0b\x46\x65\x61tureType\x12\x13\n\x0f\x46\x45\x41TURE_UNKNOWN\x10\x00\x12\x15\n\x11LANDSCAPE_COMMENT\x10\x01\"\\\n\x0c\x46\x65\x61tureState\x12\x19\n\x15\x46\x45\x41TURE_STATE_UNKNOWN\x10\x00\x12\x17\n\x13\x46\x45\x41TURE_STATE_OPEND\x10\x01\x12\x18\n\x14\x46\x45\x41TURE_STATE_CLOSED\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LiveFeatureState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIVEFEATURESTATE._serialized_start=39
  _LIVEFEATURESTATE._serialized_end=324
  _LIVEFEATURESTATE_FEATURETYPE._serialized_start=173
  _LIVEFEATURESTATE_FEATURETYPE._serialized_end=230
  _LIVEFEATURESTATE_FEATURESTATE._serialized_start=232
  _LIVEFEATURESTATE_FEATURESTATE._serialized_end=324
# @@protoc_insertion_point(module_scope)
