# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderCreateRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n SessionFolderCreateRequest.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x10\x43hatTarget.proto\"\x81\x01\n\x1aSessionFolderCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65xtra\x18\x02 \x01(\x0c\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12\x35\n\nchatTarget\x18\x04 \x03(\x0b\x32!.AcFunDanmu.Im.Message.ChatTargetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderCreateRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERCREATEREQUEST._serialized_start=90
  _SESSIONFOLDERCREATEREQUEST._serialized_end=219
# @@protoc_insertion_point(module_scope)
