syntax = "proto3";

package AcFunDanmu.Im.Basic;

import "FrontendInfo.proto";
import "RequsetBasicInfo.proto";
import "SettingInfo.proto";
import "UserInstance.proto";

message UpstreamPayload {
	string command = 1;
	int64 seqId = 2;
	uint32 retryCount = 3;
	bytes payloadData = 4;
	UserInstance userInstance = 5;
	int32 errorCode = 6;
	SettingInfo settingInfo = 7;
	RequsetBasicInfo requestBasicInfo = 8;
	string subBiz = 9;
	FrontendInfo frontendInfo = 10;
	string kpn = 11;
	bool anonymouseUser = 12;
	string laneId = 13;
}
