# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatSession.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2
import Message_pb2 as Message__pb2
import MessageReceiveStatus_pb2 as MessageReceiveStatus__pb2
import RemindBody_pb2 as RemindBody__pb2
import SessionStatus_pb2 as SessionStatus__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x43hatSession.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x14\x43hatTargetType.proto\x1a\rMessage.proto\x1a\x1aMessageReceiveStatus.proto\x1a\x10RemindBody.proto\x1a\x13SessionStatus.proto\x1a\nUser.proto\"\xd0\x05\n\x0b\x43hatSession\x12)\n\x06target\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08maxSeqId\x18\x02 \x01(\x03\x12\x11\n\treadSeqId\x18\x03 \x01(\x03\x12\x16\n\x0eunreadMsgCount\x18\x04 \x01(\x05\x12\x35\n\rlatestMessage\x18\x05 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12=\n\x0e\x63hatTargetType\x18\x08 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetType\x12\x10\n\x08targetId\x18\t \x01(\x03\x12\x12\n\nactiveTime\x18\n \x01(\x03\x12\x10\n\x08priority\x18\x0b \x01(\x05\x12\x12\n\ncategoryId\x18\x0c \x01(\x05\x12\x0e\n\x06\x63ursor\x18\r \x01(\t\x12\x13\n\x0b\x61\x63\x63ountType\x18\x0e \x01(\x05\x12\x18\n\x10\x61ggregateSession\x18\x0f \x01(\x08\x12\x16\n\x0ejumpCategoryId\x18\x10 \x01(\x05\x12\x10\n\x08\x65xpireAt\x18\x11 \x01(\x03\x12\x15\n\reffectiveFrom\x18\x12 \x01(\x03\x12\x13\n\x0bstrTargetId\x18\x13 \x01(\t\x12\x35\n\nremindBody\x18\x14 \x03(\x0b\x32!.AcFunDanmu.Im.Message.RemindBody\x12\x17\n\x0ftargetReadSeqId\x18\x15 \x01(\x03\x12\x0c\n\x04mute\x18\x16 \x01(\x08\x12\x34\n\x06status\x18\x17 \x01(\x0e\x32$.AcFunDanmu.Im.Message.SessionStatus\x12I\n\x14messageReceiveStatus\x18\x18 \x01(\x0e\x32+.AcFunDanmu.Im.Message.MessageReceiveStatus\x12\r\n\x05\x65xtra\x18\x19 \x01(\x0c\x12\x14\n\x0cmarkedUnread\x18\x1a \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatSession_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATSESSION._serialized_start=161
  _CHATSESSION._serialized_end=881
# @@protoc_insertion_point(module_scope)
