# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LocaleMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LocaleMessage.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa0\x01\n\rLocaleMessage\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12J\n\x0c\x65rrorMessage\x18\x02 \x03(\x0b\x32\x34.AcFunDanmu.Im.Basic.LocaleMessage.ErrorMessageEntry\x1a\x33\n\x11\x45rrorMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LocaleMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._options = None
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_options = b'8\001'
  _LOCALEMESSAGE._serialized_start=45
  _LOCALEMESSAGE._serialized_end=205
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_start=154
  _LOCALEMESSAGE_ERRORMESSAGEENTRY._serialized_end=205
# @@protoc_insertion_point(module_scope)
