# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x43ommonStateSignalChatEnd.proto\x12\nAcFunDanmu\"\xaa\x03\n\x18\x43ommonStateSignalChatEnd\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12=\n\x07\x65ndType\x18\x02 \x01(\x0e\x32,.AcFunDanmu.CommonStateSignalChatEnd.EndType\x12:\n\x01\x63\x18\x03 \x01(\x0b\x32/.AcFunDanmu.CommonStateSignalChatEnd.BannedInfo\x1a\x38\n\nBannedInfo\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\"\xc8\x01\n\x07\x45ndType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10\x43\x41NCEL_BY_AUTHOR\x10\x01\x12\x11\n\rEND_BY_AUTHOR\x10\x02\x12\x10\n\x0c\x45ND_BY_GUEST\x10\x03\x12\x10\n\x0cGUEST_REJECT\x10\x04\x12\x11\n\rGUEST_TIMEOUT\x10\x05\x12\x1b\n\x17GUEST_HEARTBEAT_TIMEOUT\x10\x06\x12\x1c\n\x18\x41UTHOR_HEARTBEAT_TIMEOUT\x10\x07\x12\x15\n\x11PEER_LIVE_STOPPED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATEND._serialized_start=47
  _COMMONSTATESIGNALCHATEND._serialized_end=473
  _COMMONSTATESIGNALCHATEND_BANNEDINFO._serialized_start=214
  _COMMONSTATESIGNALCHATEND_BANNEDINFO._serialized_end=270
  _COMMONSTATESIGNALCHATEND_ENDTYPE._serialized_start=273
  _COMMONSTATESIGNALCHATEND_ENDTYPE._serialized_end=473
# @@protoc_insertion_point(module_scope)
