syntax = "proto3";

package AcFunDanmu.Im.Message;

import "I18nCopyWriting.proto";
import "RichTextNoticeMessage.proto";

message NoticeMessage {
	RichTextNoticeMessage richTextNotice = 2;
	string msg = 5;
	Im.Basic.I18nCopyWriting i18nCopyWriting = 10;
}
