# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionFolderUpdateRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n SessionFolderUpdateRequest.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\"\x91\x02\n\x1aSessionFolderUpdateRequest\x12\x17\n\x0fsessionFolderId\x18\x01 \x01(\t\x12Y\n\x06\x66ields\x18\x02 \x03(\x0e\x32I.AcFunDanmu.Im.Cloud.SessionFolder.SessionFolderUpdateRequest.UpdateField\x12\x12\n\nfolderName\x18\x03 \x01(\t\x12\x0f\n\x07iconUrl\x18\x04 \x01(\t\x12\r\n\x05\x65xtra\x18\x05 \x01(\x0c\"K\n\x0bUpdateField\x12\x12\n\x0eUN_KNOWN_FIELD\x10\x00\x12\x0f\n\x0b\x46OLDER_NAME\x10\x01\x12\x0c\n\x08ICON_URL\x10\x02\x12\t\n\x05\x45XTRA\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionFolderUpdateRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONFOLDERUPDATEREQUEST._serialized_start=72
  _SESSIONFOLDERUPDATEREQUEST._serialized_end=345
  _SESSIONFOLDERUPDATEREQUEST_UPDATEFIELD._serialized_start=270
  _SESSIONFOLDERUPDATEREQUEST_UPDATEFIELD._serialized_end=345
# @@protoc_insertion_point(module_scope)
