# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinkErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LinkErrorCode.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic*\xcd\x07\n\rLinkErrorCode\x12\x08\n\x04SUCC\x10\x00\x12\x0e\n\tBASIC_MIN\x10\x90N\x12\x13\n\x0eINTERNEL_ERROR\x10\x91N\x12\x18\n\x13SERVICE_UNAVAILABLE\x10\x92N\x12\x14\n\x0fSERVICE_TIMEOUT\x10\x93N\x12\x12\n\rINVALID_TOKEN\x10\x94N\x12\x1e\n\x19REG_ENCYRPT_WITHOUT_TOKEN\x10\x95N\x12\x16\n\x11PARSE_PB_HDR_FAIL\x10\x96N\x12\x16\n\x11PARSE_PB_PLD_FAIL\x10\x97N\x12\x12\n\rPARSE_PB_FAIL\x10\x98N\x12\x15\n\x10\x44\x45\x43ODED_LEN_FAIL\x10\x99N\x12\x10\n\x0bINVALID_KEY\x10\x9aN\x12\x11\n\x0c\x45NCRYPT_FAIL\x10\x9bN\x12\x11\n\x0c\x44\x45\x43RYPT_FAIL\x10\x9cN\x12\x10\n\x0bINVALID_TAG\x10\x9dN\x12\x10\n\x0bINVALID_VER\x10\x9eN\x12\x1a\n\x15INVALID_COMPRESS_TYPE\x10\xa0N\x12\x19\n\x14INVALID_ENCRYPT_TYPE\x10\xa1N\x12\x11\n\x0cNOT_REGISTER\x10\xa2N\x12\x14\n\x0fUSER_NOT_ONLINE\x10\xa3N\x12\x14\n\x0fINVALID_COMMAND\x10\xa4N\x12\x1a\n\x15PUSH_UNREGISTER_ERROR\x10\xa5N\x12\x10\n\x0bINVALID_SID\x10\xa6N\x12\x18\n\x13INVALID_INSTANCE_ID\x10\xa7N\x12\x1c\n\x17\x43LIENT_LOCALE_NOT_MATCH\x10\xa8N\x12#\n\x1eINVALID_TOKEN_PASSWORD_CHANGED\x10\xa9N\x12 \n\x1bINVALID_TOKEN_TOKEN_EXPIRED\x10\xaaN\x12$\n\x1fINVALID_TOKEN_TOKEN_VALUE_ERROR\x10\xabN\x12(\n#INVALID_TOKEN_LOGIN_ON_OTHER_DEVICE\x10\xacN\x12\x14\n\x0f\x46ORCE_RECONNECT\x10\xadN\x12\x13\n\x0e\x43LIENT_TIMEOUT\x10\xaeN\x12\x15\n\x10INVALID_ARGUMENT\x10\xafN\x12\x19\n\x14INVALID_FORMAT_TOKEN\x10\xb0N\x12\x12\n\rEMPTY_PAYLOAD\x10\xb1N\x12\x12\n\rCOMPRESS_FAIL\x10\xb2N\x12\x14\n\x0f\x44\x45\x43OMPRESS_FAIL\x10\xb3N\x12\x11\n\x0cOUT_OF_ORDER\x10\xb4N\x12\x11\n\x0cOUT_OF_LIMIT\x10\xb5N\x12\x16\n\x11TOO_LARGE_PAYLOAD\x10\xb6N\x12\x15\n\x10\x41NONYMOUSE_ERROR\x10\xb7N\x12\x0f\n\tBASIC_MAX\x10\x9f\x9c\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LinkErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LINKERRORCODE._serialized_start=45
  _LINKERRORCODE._serialized_end=1018
# @@protoc_insertion_point(module_scope)
