# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TokenInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fTokenInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x85\x01\n\tTokenInfo\x12;\n\ttokenType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Basic.TokenInfo.TokenType\x12\r\n\x05token\x18\x02 \x01(\x0c\",\n\tTokenType\x12\x0c\n\x08kInvalid\x10\x00\x12\x11\n\rkServiceToken\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'TokenInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOKENINFO._serialized_start=41
  _TOKENINFO._serialized_end=174
  _TOKENINFO_TOKENTYPE._serialized_start=130
  _TOKENINFO_TOKENTYPE._serialized_end=174
# @@protoc_insertion_point(module_scope)
