# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalLiveManagerState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(CommonNotifySignalLiveManagerState.proto\x12\nAcFunDanmu\"\xd3\x01\n\"CommonNotifySignalLiveManagerState\x12J\n\x05state\x18\x01 \x01(\x0e\x32;.AcFunDanmu.CommonNotifySignalLiveManagerState.ManagerState\"a\n\x0cManagerState\x12\x19\n\x15MANAGER_STATE_UNKNOWN\x10\x00\x12\x11\n\rMANAGER_ADDED\x10\x01\x12\x13\n\x0fMANAGER_REMOVED\x10\x02\x12\x0e\n\nIS_MANAGER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalLiveManagerState_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE._serialized_start=57
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE._serialized_end=268
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE_MANAGERSTATE._serialized_start=171
  _COMMONNOTIFYSIGNALLIVEMANAGERSTATE_MANAGERSTATE._serialized_end=268
# @@protoc_insertion_point(module_scope)
