# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: acfun.live.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61\x63\x66un.live.proto\x12\nAcFunDanmu\"-\n\rAcFunUserInfo\x12\x0e\n\x06userId\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x1c\x41\x63\x66unActionSignalThrowBanana\x12*\n\x07visitor\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x12\n\nsendTimeMs\x18\x03 \x01(\x03\"2\n\x1b\x41\x63\x66unStateSignalDisplayInfo\x12\x13\n\x0b\x62\x61nanaCount\x18\x01 \x01(\t\"\x89\x01\n\x19\x41\x63\x66unActionSignalJoinClub\x12+\n\x08\x66\x61nsInfo\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12+\n\x08uperInfo\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.AcFunUserInfo\x12\x12\n\njoinTimeMs\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'acfun_live_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACFUNUSERINFO._serialized_start=32
  _ACFUNUSERINFO._serialized_end=77
  _ACFUNACTIONSIGNALTHROWBANANA._serialized_start=79
  _ACFUNACTIONSIGNALTHROWBANANA._serialized_end=188
  _ACFUNSTATESIGNALDISPLAYINFO._serialized_start=190
  _ACFUNSTATESIGNALDISPLAYINFO._serialized_end=240
  _ACFUNACTIONSIGNALJOINCLUB._serialized_start=243
  _ACFUNACTIONSIGNALJOINCLUB._serialized_end=380
# @@protoc_insertion_point(module_scope)
