# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CallStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43\x61llStatus.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call*{\n\nCallStatus\x12\x0e\n\nCS_UNKNOWN\x10\x00\x12\x0b\n\x07WAITING\x10\x01\x12\x0b\n\x07\x43\x41LLING\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x46INISHED\x10\x04\x12\r\n\tCANCELLED\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\x12\x0b\n\x07\x42USYING\x10\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CallStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALLSTATUS._serialized_start=52
  _CALLSTATUS._serialized_end=175
# @@protoc_insertion_point(module_scope)
