# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeviceInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x44\x65viceInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xa2\x03\n\nDeviceInfo\x12\x42\n\x0cplatformType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.DeviceInfo.PlatformType\x12\x11\n\tosVersion\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65viceModel\x18\x03 \x01(\t\x12\x0f\n\x07imeiMd5\x18\x04 \x01(\x0c\x12\x10\n\x08\x64\x65viceId\x18\x05 \x01(\t\x12\x0f\n\x07softDid\x18\x06 \x01(\t\x12\x0f\n\x07kwaiDid\x18\x07 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x08 \x01(\t\x12\x12\n\ndeviceName\x18\t \x01(\t\"\xb8\x01\n\x0cPlatformType\x12\x0c\n\x08kInvalid\x10\x00\x12\x0c\n\x08kAndroid\x10\x01\x12\x08\n\x04kiOS\x10\x02\x12\x0c\n\x08kWindows\x10\x03\x12\x12\n\x0eWECHAT_ANDROID\x10\x04\x12\x0e\n\nWECHAT_IOS\x10\x05\x12\x06\n\x02H5\x10\x06\x12\x0e\n\nH5_ANDROID\x10\x07\x12\n\n\x06H5_IOS\x10\x08\x12\x0e\n\nH5_WINDOWS\x10\t\x12\n\n\x06H5_MAC\x10\n\x12\x10\n\x0ckPlatformNum\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DeviceInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICEINFO._serialized_start=42
  _DEVICEINFO._serialized_end=460
  _DEVICEINFO_PLATFORMTYPE._serialized_start=276
  _DEVICEINFO_PLATFORMTYPE._serialized_end=460
# @@protoc_insertion_point(module_scope)
