# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$CommonStateSignalAuthorChatEnd.proto\x12\nAcFunDanmu\"\xe4\x02\n\x1e\x43ommonStateSignalAuthorChatEnd\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12\x43\n\x07\x65ndType\x18\x02 \x01(\x0e\x32\x32.AcFunDanmu.CommonStateSignalAuthorChatEnd.EndType\x12\x11\n\tendLiveId\x18\x03 \x01(\t\"\xd3\x01\n\x07\x45ndType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x15\n\x11\x43\x41NCEL_BY_INVITER\x10\x01\x12\x12\n\x0e\x45ND_BY_INVITER\x10\x02\x12\x12\n\x0e\x45ND_BY_INVITEE\x10\x03\x12\x12\n\x0eINVITEE_REJECT\x10\x04\x12\x13\n\x0fINVITEE_TIMEOUT\x10\x05\x12\x1d\n\x19INVITEE_HEARTBEAT_TIMEOUT\x10\x06\x12\x1d\n\x19INVITER_HEARTBEAT_TIMEOUT\x10\x07\x12\x15\n\x11PEER_LIVE_STOPPED\x10\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATEND._serialized_start=53
  _COMMONSTATESIGNALAUTHORCHATEND._serialized_end=409
  _COMMONSTATESIGNALAUTHORCHATEND_ENDTYPE._serialized_start=198
  _COMMONSTATESIGNALAUTHORCHATEND_ENDTYPE._serialized_end=409
# @@protoc_insertion_point(module_scope)
