syntax = "proto3";

package AcFunDanmu.Im.Cloud.Message;

message Video {
	string uri = 1;
	int32 duration = 2;
	int32 width = 3;
	int32 height = 4;
	string coverUri = 5;
	string type = 6;
	int64 contentLength = 7;
}
