# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveScStateSignal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveStateSignalItem_pb2 as ZtLiveStateSignalItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ZtLiveScStateSignal.proto\x12\nAcFunDanmu\x1a\x1bZtLiveStateSignalItem.proto\"F\n\x13ZtLiveScStateSignal\x12/\n\x04item\x18\x01 \x03(\x0b\x32!.AcFunDanmu.ZtLiveStateSignalItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveScStateSignal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESCSTATESIGNAL._serialized_start=70
  _ZTLIVESCSTATESIGNAL._serialized_end=140
# @@protoc_insertion_point(module_scope)
