# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMessageReceiptCountGetRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&B2CMessageReceiptCountGetRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"F\n B2CMessageReceiptCountGetRequest\x12\r\n\x05seqId\x18\x01 \x03(\x03\x12\x13\n\x0bstrTargetId\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMessageReceiptCountGetRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMESSAGERECEIPTCOUNTGETREQUEST._serialized_start=65
  _B2CMESSAGERECEIPTCOUNTGETREQUEST._serialized_end=135
# @@protoc_insertion_point(module_scope)
