# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalTopUsers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x43ommonStateSignalTopUsers.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xe4\x01\n\x19\x43ommonStateSignalTopUsers\x12;\n\x04user\x18\x01 \x03(\x0b\x32-.AcFunDanmu.CommonStateSignalTopUsers.TopUser\x1a\x89\x01\n\x07TopUser\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x1e\n\x16\x63ustomWatchingListData\x18\x03 \x01(\t\x12\x19\n\x11\x64isplaySendAmount\x18\x04 \x01(\t\x12\x15\n\ranonymousUser\x18\x05 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalTopUsers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALTOPUSERS._serialized_start=70
  _COMMONSTATESIGNALTOPUSERS._serialized_end=298
  _COMMONSTATESIGNALTOPUSERS_TOPUSER._serialized_start=161
  _COMMONSTATESIGNALTOPUSERS_TOPUSER._serialized_end=298
# @@protoc_insertion_point(module_scope)
