# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AppInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rAppInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xe9\x01\n\x07\x41ppInfo\x12\x0f\n\x07\x61ppName\x18\x01 \x01(\t\x12\x12\n\nappVersion\x18\x02 \x01(\t\x12\x12\n\nappChannel\x18\x03 \x01(\t\x12\x12\n\nsdkVersion\x18\x04 \x01(\t\x12\x13\n\x0blinkVersion\x18\x05 \x01(\t\x12\x46\n\rextensionInfo\x18\x0b \x03(\x0b\x32/.AcFunDanmu.Im.Basic.AppInfo.ExtensionInfoEntry\x1a\x34\n\x12\x45xtensionInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AppInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPINFO_EXTENSIONINFOENTRY._options = None
  _APPINFO_EXTENSIONINFOENTRY._serialized_options = b'8\001'
  _APPINFO._serialized_start=39
  _APPINFO._serialized_end=272
  _APPINFO_EXTENSIONINFOENTRY._serialized_start=220
  _APPINFO_EXTENSIONINFOENTRY._serialized_end=272
# @@protoc_insertion_point(module_scope)
