# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RegisterRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AppInfo_pb2 as AppInfo__pb2
import DeviceInfo_pb2 as DeviceInfo__pb2
import EnvInfo_pb2 as EnvInfo__pb2
import PushServiceToken_pb2 as PushServiceToken__pb2
import ZtCommonInfo_pb2 as ZtCommonInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15RegisterRequest.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\rAppInfo.proto\x1a\x10\x44\x65viceInfo.proto\x1a\rEnvInfo.proto\x1a\x16PushServiceToken.proto\x1a\x12ZtCommonInfo.proto\"\xe5\x05\n\x0fRegisterRequest\x12-\n\x07\x61ppInfo\x18\x01 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.AppInfo\x12\x33\n\ndeviceInfo\x18\x02 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.DeviceInfo\x12-\n\x07\x65nvInfo\x18\x03 \x01(\x0b\x32\x1c.AcFunDanmu.Im.Basic.EnvInfo\x12K\n\x0epresenceStatus\x18\x04 \x01(\x0e\x32\x33.AcFunDanmu.Im.Basic.RegisterRequest.PresenceStatus\x12J\n\x0f\x61ppActiveStatus\x18\x05 \x01(\x0e\x32\x31.AcFunDanmu.Im.Basic.RegisterRequest.ActiveStatus\x12\x17\n\x0f\x61ppCustomStatus\x18\x06 \x01(\x0c\x12?\n\x10pushServiceToken\x18\x07 \x01(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x12\n\ninstanceId\x18\x08 \x01(\x03\x12\x43\n\x14pushServiceTokenList\x18\t \x03(\x0b\x32%.AcFunDanmu.Im.Basic.PushServiceToken\x12\x1c\n\x14keepaliveIntervalSec\x18\n \x01(\x05\x12\x37\n\x0cztCommonInfo\x18\x0b \x01(\x0b\x32!.AcFunDanmu.Im.Basic.ZtCommonInfo\x12\x15\n\ripv6Available\x18\x0c \x01(\x08\";\n\x0ePresenceStatus\x12\x14\n\x10kPresenceOffline\x10\x00\x12\x13\n\x0fkPresenceOnline\x10\x01\"H\n\x0c\x41\x63tiveStatus\x12\x0c\n\x08kInvalid\x10\x00\x12\x14\n\x10kAppInForeground\x10\x01\x12\x14\n\x10kAppInBackground\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RegisterRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERREQUEST._serialized_start=139
  _REGISTERREQUEST._serialized_end=880
  _REGISTERREQUEST_PRESENCESTATUS._serialized_start=747
  _REGISTERREQUEST_PRESENCESTATUS._serialized_end=806
  _REGISTERREQUEST_ACTIVESTATUS._serialized_start=808
  _REGISTERREQUEST_ACTIVESTATUS._serialized_end=880
# @@protoc_insertion_point(module_scope)
