# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ClientStatisticalDataConfig_pb2 as ClientStatisticalDataConfig__pb2
import NetworkQualityDetectionConfig_pb2 as NetworkQualityDetectionConfig__pb2
import SubBizAggregationConfig_pb2 as SubBizAggregationConfig__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x43lientConfig.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\x1a!ClientStatisticalDataConfig.proto\x1a#NetworkQualityDetectionConfig.proto\x1a\x1dSubBizAggregationConfig.proto\"\x89\x08\n\x0c\x43lientConfig\x12\x1f\n\x17\x66\x65tchUserStatusInterval\x18\x01 \x01(\x05\x12$\n\x1c\x63hannelUserHeartbeatInterval\x18\x02 \x01(\x05\x12`\n\x1dnetworkQualityDetectionConfig\x18\x03 \x01(\x0b\x32\x39.AcFunDanmu.Im.Cloud.Config.NetworkQualityDetectionConfig\x12#\n\x1binputtingTipDisplayInterval\x18\x04 \x01(\x05\x12 \n\x18\x62\x61tchSendMessageMaxCount\x18\x05 \x01(\x05\x12\x1f\n\x17resourceUploadingDomain\x18\x06 \x01(\t\x12\x1b\n\x13ktpFileLenThreshold\x18\x07 \x01(\x05\x12\x1a\n\x12ktpUploadingDomain\x18\x08 \x01(\t\x12\x1f\n\x17\x63lientSyncMinIntervalMs\x18\t \x01(\x05\x12$\n\x1c\x64ownloadFileMaxLenPerRequest\x18\n \x01(\x05\x12\\\n\x1b\x63lientStatisticalDataConfig\x18\x0b \x01(\x0b\x32\x37.AcFunDanmu.Im.Cloud.Config.ClientStatisticalDataConfig\x12\x1d\n\x15maxMessageBytesLength\x18\x0c \x01(\x05\x12\'\n\x1fsessionDeletionNotOverAllDevice\x18\r \x01(\x08\x12T\n\x17subBizAggregationConfig\x18\x0e \x01(\x0b\x32\x33.AcFunDanmu.Im.Cloud.Config.SubBizAggregationConfig\x12$\n\x1c\x63ountVisibleMessageThreshold\x18\x0f \x01(\x05\x12\x33\n+disableSessionSyncWhenAppSwitchToForeground\x18\x10 \x01(\x08\x12*\n\"maxMessagesPreloadAfterSessionSync\x18\x11 \x01(\x05\x12\x35\n-maxSessionsNeedPreloadMessageAfterSessionSync\x18\x12 \x01(\x05\x12\x15\n\rztImApiDomain\x18\x13 \x01(\t\x12 \n\x18voiceCallTimeoutInterval\x18\x14 \x01(\x05\x12\"\n\x1avoiceCallHeartbeatInterval\x18\x15 \x01(\x05\x12\x18\n\x10\x63lickMessageType\x18\x16 \x03(\x05\x12\x1c\n\x14\x61utoRetryMaxInterval\x18\x17 \x01(\x05\x12\x19\n\x11\x61utoRetryMaxTimes\x18\x18 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTCONFIG._serialized_start=154
  _CLIENTCONFIG._serialized_end=1187
# @@protoc_insertion_point(module_scope)
