# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CsEvaluationMessageContent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CsEvaluationMessageContent.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\xcd\x03\n\x1a\x43sEvaluationMessageContent\x12\x10\n\x08targetId\x18\x01 \x01(\x03\x12\x62\n\x10\x65valuationOption\x18\x02 \x03(\x0b\x32H.AcFunDanmu.Im.Cloud.Message.CsEvaluationMessageContent.EvaluationOption\x12\r\n\x05title\x18\x03 \x01(\t\x1a\xe7\x01\n\x10\x45valuationOption\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0f\n\x07grayUrl\x18\x02 \x01(\t\x12\x11\n\toptionTxt\x18\x03 \x01(\t\x12\x12\n\noptionType\x18\x04 \x01(\x05\x12\x10\n\x08selected\x18\x05 \x01(\x08\x12j\n\x0fsecondaryOption\x18\x06 \x03(\x0b\x32Q.AcFunDanmu.Im.Cloud.Message.CsEvaluationMessageContent.EvaluationSecondaryOption\x12\x10\n\x08subTitle\x18\x07 \x01(\t\x1a@\n\x19\x45valuationSecondaryOption\x12\x10\n\x08selected\x18\x01 \x01(\x08\x12\x11\n\toptionTxt\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CsEvaluationMessageContent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSEVALUATIONMESSAGECONTENT._serialized_start=66
  _CSEVALUATIONMESSAGECONTENT._serialized_end=527
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONOPTION._serialized_start=230
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONOPTION._serialized_end=461
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONSECONDARYOPTION._serialized_start=463
  _CSEVALUATIONMESSAGECONTENT_EVALUATIONSECONDARYOPTION._serialized_end=527
# @@protoc_insertion_point(module_scope)
