# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtCommonInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ZtCommonInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xf4\x01\n\x0cZtCommonInfo\x12\x0b\n\x03kpn\x18\x01 \x01(\t\x12\x0b\n\x03kpf\x18\x02 \x01(\t\x12\x0e\n\x06subBiz\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\x12\x0b\n\x03\x64id\x18\x05 \x01(\t\x12\x10\n\x08\x63lientIp\x18\x06 \x01(\x03\x12\x0e\n\x06\x61ppVer\x18\x07 \x01(\t\x12\x0b\n\x03ver\x18\x08 \x01(\t\x12\x0b\n\x03lat\x18\t \x01(\t\x12\x0b\n\x03lon\x18\n \x01(\t\x12\x0b\n\x03mod\x18\x0b \x01(\t\x12\x0b\n\x03net\x18\x0c \x01(\t\x12\x0b\n\x03sys\x18\r \x01(\t\x12\t\n\x01\x63\x18\x0e \x01(\t\x12\x10\n\x08language\x18\x0f \x01(\t\x12\x13\n\x0b\x63ountryCode\x18\x10 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtCommonInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTCOMMONINFO._serialized_start=44
  _ZTCOMMONINFO._serialized_end=288
# @@protoc_insertion_point(module_scope)
