# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LeaveSession.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12LeaveSession.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x10\x43hatTarget.proto\"l\n\x0cLeaveSession\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\x11\n\textraInfo\x18\x02 \x01(\t\x12\x12\n\nactionType\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LeaveSession_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEAVESESSION._serialized_start=63
  _LEAVESESSION._serialized_end=171
# @@protoc_insertion_point(module_scope)
