syntax = "proto3";

package AcFunDanmu;

import "ChatMediaType.proto";

message CommonStateSignalChatCall {
	string chatId = 1;
	string liveId = 2;
	int64 callTimestampMs = 3;
	ChatMediaType mediaType = 4;
}
