# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMember.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11GroupMember.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\nUser.proto\"\xa8\x04\n\x0bGroupMember\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x16\n\x0e\x61ntiDisturbing\x18\x03 \x01(\x08\x12J\n\x06status\x18\x04 \x01(\x0e\x32:.AcFunDanmu.Im.Cloud.Message.GroupMember.GroupMemberStatus\x12\x11\n\tinviterId\x18\x05 \x01(\x03\x12\x10\n\x08joinTime\x18\x06 \x01(\x03\x12\x12\n\ncreateTime\x18\x07 \x01(\x03\x12\x12\n\nupdateTime\x18\x08 \x01(\x03\x12\x46\n\x04role\x18\t \x01(\x0e\x32\x38.AcFunDanmu.Im.Cloud.Message.GroupMember.GroupMemberRole\x12\x10\n\x08\x66indType\x18\n \x01(\x05\x12\x1b\n\x13keepSilenceDeadline\x18\x0b \x01(\x03\"b\n\x11GroupMemberStatus\x12\x19\n\x15UNKNOWN_MEMBER_STATUS\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x0b\n\x07QUITTED\x10\x02\x12\n\n\x06KICKED\x10\x03\x12\r\n\tDISMISSED\x10\x04\"R\n\x0fGroupMemberRole\x12\x10\n\x0cUNKNOWN_ROLE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\x0b\n\x07MANAGER\x10\x03\x12\t\n\x05ROBOT\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMember_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBER._serialized_start=63
  _GROUPMEMBER._serialized_end=615
  _GROUPMEMBER_GROUPMEMBERSTATUS._serialized_start=433
  _GROUPMEMBER_GROUPMEMBERSTATUS._serialized_end=531
  _GROUPMEMBER_GROUPMEMBERROLE._serialized_start=533
  _GROUPMEMBER_GROUPMEMBERROLE._serialized_end=615
# @@protoc_insertion_point(module_scope)
