# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EnvInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rEnvInfo.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x90\x01\n\x07\x45nvInfo\x12=\n\x0bnetworkType\x18\x01 \x01(\x0e\x32(.AcFunDanmu.Im.Basic.EnvInfo.NetworkType\x12\x0f\n\x07\x61pnName\x18\x02 \x01(\x0c\"5\n\x0bNetworkType\x12\x0c\n\x08kInvalid\x10\x00\x12\t\n\x05kWIFI\x10\x01\x12\r\n\tkCellular\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'EnvInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVINFO._serialized_start=39
  _ENVINFO._serialized_end=183
  _ENVINFO_NETWORKTYPE._serialized_start=130
  _ENVINFO_NETWORKTYPE._serialized_end=183
# @@protoc_insertion_point(module_scope)
