# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PacketHeader.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import TokenInfo_pb2 as TokenInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12PacketHeader.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x0fTokenInfo.proto\"\x84\x05\n\x0cPacketHeader\x12\r\n\x05\x61ppId\x18\x01 \x01(\x05\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x12\n\ninstanceId\x18\x03 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x44\n\x0c\x65ncodingType\x18\x06 \x01(\x0e\x32..AcFunDanmu.Im.Basic.PacketHeader.EncodingType\x12\x19\n\x11\x64\x65\x63odedPayloadLen\x18\x07 \x01(\r\x12H\n\x0e\x65ncryptionMode\x18\x08 \x01(\x0e\x32\x30.AcFunDanmu.Im.Basic.PacketHeader.EncryptionMode\x12\x31\n\ttokenInfo\x18\t \x01(\x0b\x32\x1e.AcFunDanmu.Im.Basic.TokenInfo\x12\r\n\x05seqId\x18\n \x01(\x03\x12;\n\x08\x66\x65\x61tures\x18\x0b \x03(\x0e\x32).AcFunDanmu.Im.Basic.PacketHeader.Feature\x12\x0b\n\x03kpn\x18\x0c \x01(\t\"?\n\x05\x46lags\x12\x10\n\x0ckDirUpstream\x10\x00\x12\x12\n\x0ekDirDownstream\x10\x01\x12\x0c\n\x08kDirMask\x10\x01\x1a\x02\x10\x01\"3\n\x0c\x45ncodingType\x12\x11\n\rkEncodingNone\x10\x00\x12\x10\n\x0ckEncodingLz4\x10\x01\"]\n\x0e\x45ncryptionMode\x12\x13\n\x0fkEncryptionNone\x10\x00\x12\x1b\n\x17kEncryptionServiceToken\x10\x01\x12\x19\n\x15kEncryptionSessionKey\x10\x02\")\n\x07\x46\x65\x61ture\x12\x0c\n\x08kReserve\x10\x00\x12\x10\n\x0ckCompressLz4\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PacketHeader_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PACKETHEADER_FLAGS._options = None
  _PACKETHEADER_FLAGS._serialized_options = b'\020\001'
  _PACKETHEADER._serialized_start=61
  _PACKETHEADER._serialized_end=705
  _PACKETHEADER_FLAGS._serialized_start=451
  _PACKETHEADER_FLAGS._serialized_end=514
  _PACKETHEADER_ENCODINGTYPE._serialized_start=516
  _PACKETHEADER_ENCODINGTYPE._serialized_end=567
  _PACKETHEADER_ENCRYPTIONMODE._serialized_start=569
  _PACKETHEADER_ENCRYPTIONMODE._serialized_end=662
  _PACKETHEADER_FEATURE._serialized_start=664
  _PACKETHEADER_FEATURE._serialized_end=705
# @@protoc_insertion_point(module_scope)
