syntax = "proto3";

package AcFunDanmu.Im.Cloud.Message;

import "User.proto";

message GroupMembersBriefInfo {
	int32 memberCount = 1;
	repeated Im.Basic.User topMembers = 2;
	int64 lastUpdateTime = 3;
}
