syntax = "proto3";

package AcFunDanmu.Im.Cloud.Data.Update;

enum KsImDataUpdateType {
	INVALID = 0;
	GROUP_INFO_UPDATE = 1;
	GROUP_MEMBER_LIST_UPDATE = 2;
	YOU_BE_KICKED = 3;
	MESSAGE_READ_EVENT = 4;
	MESSAGE_RECEIPT_EVENT = 5;
	SESSION_UPDATE = 6;
	SESSION_FOLDER_UPDATE = 7;
	FAVORITE_LIST_UPDATE = 8;
	SESSION_TAG_UPDATE = 9;
	MESSAGE_CLICKED = 10;
}
