# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatCall.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatMediaType_pb2 as ChatMediaType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x43ommonStateSignalChatCall.proto\x12\nAcFunDanmu\x1a\x13\x43hatMediaType.proto\"\x82\x01\n\x19\x43ommonStateSignalChatCall\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12\x0e\n\x06liveId\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61llTimestampMs\x18\x03 \x01(\x03\x12,\n\tmediaType\x18\x04 \x01(\x0e\x32\x19.AcFunDanmu.ChatMediaTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatCall_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATCALL._serialized_start=69
  _COMMONSTATESIGNALCHATCALL._serialized_end=199
# @@protoc_insertion_point(module_scope)
