# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatAccept.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonStateSignalAuthorChatAccept.proto\x12\nAcFunDanmu\"Q\n!CommonStateSignalAuthorChatAccept\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12\x16\n\x0e\x61ryaSignalInfo\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatAccept_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATACCEPT._serialized_start=55
  _COMMONSTATESIGNALAUTHORCHATACCEPT._serialized_end=136
# @@protoc_insertion_point(module_scope)
