# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CPullOldResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x42\x32\x43PullOldResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\rMessage.proto\"Z\n\x12\x42\x32\x43PullOldResponse\x12\x30\n\x08messages\x18\x01 \x03(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12\x12\n\nserverTime\x18\x02 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CPullOldResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CPULLOLDRESPONSE._serialized_start=66
  _B2CPULLOLDRESPONSE._serialized_end=156
# @@protoc_insertion_point(module_scope)
