# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SdkOption.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fSdkOption.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\x81\x01\n\tSdkOption\x12\x1d\n\x15reportIntervalSeconds\x18\x01 \x01(\x05\x12\x16\n\x0ereportSecurity\x18\x02 \x01(\t\x12$\n\x1clz4CompressionThresholdBytes\x18\x03 \x01(\x05\x12\x17\n\x0fnetCheckServers\x18\x04 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SdkOption_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SDKOPTION._serialized_start=41
  _SDKOPTION._serialized_end=170
# @@protoc_insertion_point(module_scope)
