# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionTagSyncResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionTagBasic_pb2 as SessionTagBasic__pb2
import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cSessionTagSyncResponse.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.SessionTag\x1a\x15SessionTagBasic.proto\x1a\x10SyncCookie.proto\"\x92\x01\n\x16SessionTagSyncResponse\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12\x43\n\nsessionTag\x18\x02 \x03(\x0b\x32/.AcFunDanmu.Im.Cloud.SessionTag.SessionTagBasicb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionTagSyncResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONTAGSYNCRESPONSE._serialized_start=106
  _SESSIONTAGSYNCRESPONSE._serialized_end=252
# @@protoc_insertion_point(module_scope)
