# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Attachment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AudioAttachment_pb2 as AudioAttachment__pb2
import ImageAttachment_pb2 as ImageAttachment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x41ttachment.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x15\x41udioAttachment.proto\x1a\x15ImageAttachment.proto\"\xa0\x01\n\nAttachment\x12\x41\n\x0fimageAttachment\x18\x01 \x01(\x0b\x32&.AcFunDanmu.Im.Message.ImageAttachmentH\x00\x12\x41\n\x0f\x61udioAttachment\x18\x02 \x01(\x0b\x32&.AcFunDanmu.Im.Message.AudioAttachmentH\x00\x42\x0c\n\nattachmentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Attachment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ATTACHMENT._serialized_start=90
  _ATTACHMENT._serialized_end=250
# @@protoc_insertion_point(module_scope)
