# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalChatReady.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatMediaType_pb2 as ChatMediaType__pb2
import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n CommonStateSignalChatReady.proto\x12\nAcFunDanmu\x1a\x13\x43hatMediaType.proto\x1a\x14ZtLiveUserInfo.proto\"\x8d\x01\n\x1a\x43ommonStateSignalChatReady\x12\x0e\n\x06\x63hatId\x18\x01 \x01(\t\x12\x31\n\rguestUserInfo\x18\x02 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12,\n\tmediaType\x18\x03 \x01(\x0e\x32\x19.AcFunDanmu.ChatMediaTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalChatReady_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALCHATREADY._serialized_start=92
  _COMMONSTATESIGNALCHATREADY._serialized_end=233
# @@protoc_insertion_point(module_scope)
