syntax = "proto3";

package AcFunDanmu;

message ZtLiveCsHeartbeat {
	int64 clientTimestampMs = 1;
	int64 sequence = 2;
}

message ZtLiveCsHeartbeatAck {
	int64 serverTimestampMs = 1;
	int64 clientTimestampMs = 2;
	int64 clientSequence = 3;
}
