# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClickEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveCommonModelProto_pb2 as ZtLiveCommonModelProto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43lickEvent.proto\x12\nAcFunDanmu\x1a\x1cZtLiveCommonModelProto.proto\"e\n\nClickEvent\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x33\n\x07urlType\x18\x02 \x01(\x0e\x32\".AcFunDanmu.ZtLiveCommonModelProto\x12\x15\n\rheightPercent\x18\x03 \x01(\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClickEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLICKEVENT._serialized_start=62
  _CLICKEVENT._serialized_end=163
# @@protoc_insertion_point(module_scope)
