syntax = "proto3";

package AcFunDanmu.Im.Basic;

message AppInfo {
	string appName = 1;
	string appVersion = 2;
	string appChannel = 3;
	string sdkVersion = 4;
	string linkVersion = 5;
	map<string,string> extensionInfo = 11;
}
