# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Audio_pb2 as Audio__pb2
import Emoticon_pb2 as Emoticon__pb2
import File_pb2 as File__pb2
import Image_pb2 as Image__pb2
import Video_pb2 as Video__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bMedia.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0b\x41udio.proto\x1a\x0e\x45moticon.proto\x1a\nFile.proto\x1a\x0bImage.proto\x1a\x0bVideo.proto\"\xbb\x02\n\x05Media\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.ImageH\x00\x12\x33\n\x05\x61udio\x18\x02 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.AudioH\x00\x12\x33\n\x05video\x18\x03 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.VideoH\x00\x12\x31\n\x04\x66ile\x18\x04 \x01(\x0b\x32!.AcFunDanmu.Im.Cloud.Message.FileH\x00\x12\x39\n\x08\x65moticon\x18\x05 \x01(\x0b\x32%.AcFunDanmu.Im.Cloud.Message.EmoticonH\x00\x12\x0b\n\x03pos\x18\x14 \x01(\x05\x12\x0c\n\x04name\x18\x15 \x01(\tB\n\n\x08resourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Media_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEDIA._serialized_start=112
  _MEDIA._serialized_end=427
# @@protoc_insertion_point(module_scope)
