# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RichTextNoticeMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bRichTextNoticeMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"\xc4\x01\n\x15RichTextNoticeMessage\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.AcFunDanmu.Im.Message.RichTextNoticeMessage.RichTextItem\x1a\x61\n\x0cRichTextItem\x12\r\n\x05\x63olor\x18\x01 \x01(\x05\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03len\x18\x03 \x01(\x05\x12\x13\n\x0b\x63lickAction\x18\x04 \x01(\t\x12\x11\n\tunderline\x18\x05 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RichTextNoticeMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RICHTEXTNOTICEMESSAGE._serialized_start=55
  _RICHTEXTNOTICEMESSAGE._serialized_end=251
  _RICHTEXTNOTICEMESSAGE_RICHTEXTITEM._serialized_start=154
  _RICHTEXTNOTICEMESSAGE_RICHTEXTITEM._serialized_end=251
# @@protoc_insertion_point(module_scope)
