syntax = "proto3";

package AcFunDanmu;

import "ZtLiveUserInfo.proto";

message AuthorChatPlayerInfo {
	ZtLiveUserInfo player = 1;
	string liveId = 2;
	bool enableJumpPeerLiveRoom = 3; // enableVisit
}
