# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupSettingInvitePermission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import InvitePermissionType_pb2 as InvitePermissionType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"GroupSettingInvitePermission.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1aInvitePermissionType.proto\"o\n\x1cGroupSettingInvitePermission\x12O\n\x14invitePermissionType\x18\x01 \x01(\x0e\x32\x31.AcFunDanmu.Im.Cloud.Message.InvitePermissionTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupSettingInvitePermission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPSETTINGINVITEPERMISSION._serialized_start=95
  _GROUPSETTINGINVITEPERMISSION._serialized_end=206
# @@protoc_insertion_point(module_scope)
