syntax = "proto3";

package AcFunDanmu.Im.Basic;

import "AccessPoint.proto";

message AccessPointsConfig {
	repeated AccessPoint optimalAps = 1;
	repeated AccessPoint backupAps = 2;
	repeated uint32 availablePorts = 3;
	AccessPoint forceLastConnectedAp = 4;
}
