# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcNoticeMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import NoticePlaceholderMeta_pb2 as NoticePlaceholderMeta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ImcNoticeMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1bNoticePlaceholderMeta.proto\"\xb9\x01\n\x10ImcNoticeMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12Q\n\x15noticePlaceholderMeta\x18\x02 \x03(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.NoticePlaceholderMeta\x12\x16\n\x0enoticeMetaType\x18\x03 \x01(\x05\x12\x16\n\x0enoticeMetaInfo\x18\x04 \x01(\x0c\x12\x14\n\x0c\x64isplayStyle\x18\x05 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcNoticeMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCNOTICEMESSAGE._serialized_start=85
  _IMCNOTICEMESSAGE._serialized_end=270
# @@protoc_insertion_point(module_scope)
