# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17GroupJoinResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\x9b\x01\n\x11GroupJoinResponse\x12M\n\njoinStatus\x18\x01 \x01(\x0e\x32\x39.AcFunDanmu.Im.Cloud.Message.GroupJoinResponse.JoinStatus\"7\n\nJoinStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04SUCC\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINRESPONSE._serialized_start=57
  _GROUPJOINRESPONSE._serialized_end=212
  _GROUPJOINRESPONSE_JOINSTATUS._serialized_start=157
  _GROUPJOINRESPONSE_JOINSTATUS._serialized_end=212
# @@protoc_insertion_point(module_scope)
