# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SystemSessionFolder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SystemSessionFolder.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder*\x9e\x01\n\x13SystemSessionFolder\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12\x46OLDER_DISPATCHING\x10\x01\x12\x12\n\x0e\x46OLDER_SERVING\x10\x02\x12\x10\n\x0c\x46OLDER_REPLY\x10\x03\x12\x15\n\x11\x46OLDER_AUTO_REPLY\x10\x04\x12\x12\n\x0e\x46OLDER_TIMEOUT\x10\x05\x12\x11\n\rFOLDER_CLOSED\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SystemSessionFolder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMSESSIONFOLDER._serialized_start=65
  _SYSTEMSESSIONFOLDER._serialized_end=223
# @@protoc_insertion_point(module_scope)
