# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Reference.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fReference.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\rMessage.proto\"\xc7\x01\n\tReference\x12\x31\n\toriginMsg\x18\x01 \x01(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12M\n\x0creferenceMsg\x18\x02 \x01(\x0b\x32\x37.AcFunDanmu.Im.Cloud.Message.Reference.ReferenceMessage\x1a\x38\n\x10ReferenceMessage\x12\x13\n\x0b\x63ontentType\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Reference_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REFERENCE._serialized_start=64
  _REFERENCE._serialized_end=263
  _REFERENCE_REFERENCEMESSAGE._serialized_start=207
  _REFERENCE_REFERENCEMESSAGE._serialized_end=263
# @@protoc_insertion_point(module_scope)
