# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalCoverAuditResult.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(CommonNotifySignalCoverAuditResult.proto\x12\nAcFunDanmu\"\xd4\x01\n\"CommonNotifySignalCoverAuditResult\x12O\n\x0b\x61uditStatus\x18\x01 \x01(\x0e\x32:.AcFunDanmu.CommonNotifySignalCoverAuditResult.AuditStatus\"]\n\x0b\x41uditStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x16\n\x12\x43OVER_AUDIT_FAILED\x10\x01\x12\x18\n\x14\x43\x41PTION_AUDIT_FAILED\x10\x02\x12\x0f\n\x0b\x42OTH_FAILED\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalCoverAuditResult_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT._serialized_start=57
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT._serialized_end=269
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT_AUDITSTATUS._serialized_start=176
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT_AUDITSTATUS._serialized_end=269
# @@protoc_insertion_point(module_scope)
