# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VisibleAmountRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aVisibleAmountRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"K\n\x14VisibleAmountRequest\x12\x0e\n\x06minSeq\x18\x01 \x01(\x03\x12\x0e\n\x06maxSeq\x18\x02 \x01(\x03\x12\x13\n\x0bstrTargetId\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VisibleAmountRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISIBLEAMOUNTREQUEST._serialized_start=53
  _VISIBLEAMOUNTREQUEST._serialized_end=128
# @@protoc_insertion_point(module_scope)
