# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsHeartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveCsHeartbeat.proto\x12\nAcFunDanmu\"@\n\x11ZtLiveCsHeartbeat\x12\x19\n\x11\x63lientTimestampMs\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"d\n\x14ZtLiveCsHeartbeatAck\x12\x19\n\x11serverTimestampMs\x18\x01 \x01(\x03\x12\x19\n\x11\x63lientTimestampMs\x18\x02 \x01(\x03\x12\x16\n\x0e\x63lientSequence\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsHeartbeat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSHEARTBEAT._serialized_start=39
  _ZTLIVECSHEARTBEAT._serialized_end=103
  _ZTLIVECSHEARTBEATACK._serialized_start=105
  _ZTLIVECSHEARTBEATACK._serialized_end=205
# @@protoc_insertion_point(module_scope)
