# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveDownstreamPayloadErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ZtLiveDownstreamPayloadErrorCode.proto\x12\nAcFunDanmu*\x97\x01\n ZtLiveDownstreamPayloadErrorCode\x12\x1e\n\x1aSUCCESS_DOWNSTREAM_PAYLOAD\x10\x00\x12\x18\n\x12\x43S_CMD_PARSE_ERROR\x10\xa1\x8d\x06\x12\x1c\n\x16\x43S_CMD_CMD_NOT_SUPPORT\x10\xa2\x8d\x06\x12\x1b\n\x15\x43S_CMD_TICKET_ILLEGAL\x10\xa3\x8d\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveDownstreamPayloadErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEDOWNSTREAMPAYLOADERRORCODE._serialized_start=55
  _ZTLIVEDOWNSTREAMPAYLOADERRORCODE._serialized_end=206
# @@protoc_insertion_point(module_scope)
