# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommentNotice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Button_pb2 as Button__pb2
import ClickEvent_pb2 as ClickEvent__pb2
import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x43ommentNotice.proto\x12\nAcFunDanmu\x1a\x0c\x42utton.proto\x1a\x10\x43lickEvent.proto\x1a\x12ImageCdnNode.proto\"\xfe\x01\n\rCommentNotice\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x0c\x12\t\n\x01\x63\x18\x03 \x01(\t\x12#\n\x01\x64\x18\x04 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12#\n\x01\x65\x18\x05 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\t\n\x01\x66\x18\x06 \x01(\t\x12\t\n\x01g\x18\x07 \x01(\t\x12\x1d\n\x01h\x18\x08 \x01(\x0b\x32\x12.AcFunDanmu.Button\x12!\n\x01i\x18\t \x01(\x0b\x32\x16.AcFunDanmu.ClickEvent\x12\t\n\x01j\x18\n \x01(\x05\x12\t\n\x01k\x18\x0b \x01(\x03\x12\t\n\x01l\x18\x0c \x01(\x03\x12\t\n\x01m\x18\r \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommentNotice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMENTNOTICE._serialized_start=88
  _COMMENTNOTICE._serialized_end=342
# @@protoc_insertion_point(module_scope)
