# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupHit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14PublicGroupHit.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\"\xbe\x01\n\x0ePublicGroupHit\x12R\n\tmatchType\x18\x01 \x01(\x0e\x32?.AcFunDanmu.Im.Cloud.Search.PublicGroupHit.PublicGroupMatchType\"X\n\x14PublicGroupMatchType\x12\x10\n\x0cUNKNOWN_PGMT\x10\x00\x12\x0e\n\nGROUP_NAME\x10\x01\x12\x0c\n\x08GROUP_ID\x10\x02\x12\x10\n\x0cGROUP_NUMBER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupHit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPHIT._serialized_start=53
  _PUBLICGROUPHIT._serialized_end=243
  _PUBLICGROUPHIT_PUBLICGROUPMATCHTYPE._serialized_start=155
  _PUBLICGROUPHIT_PUBLICGROUPMATCHTYPE._serialized_end=243
# @@protoc_insertion_point(module_scope)
