# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupBasicInfo_pb2 as GroupBasicInfo__pb2
import GroupMembersBriefInfo_pb2 as GroupMembersBriefInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fGroupInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x14GroupBasicInfo.proto\x1a\x1bGroupMembersBriefInfo.proto\"\x9e\x01\n\tGroupInfo\x12>\n\tbasicInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Message.GroupBasicInfo\x12Q\n\x15groupMembersBriefInfo\x18\x02 \x01(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.GroupMembersBriefInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINFO._serialized_start=100
  _GROUPINFO._serialized_end=258
# @@protoc_insertion_point(module_scope)
