# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMerchantSessionFolderEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionReference_pb2 as SessionReference__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#B2CMerchantSessionFolderEvent.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x16SessionReference.proto\x1a\nUser.proto\"\x89\x02\n\x1d\x42\x32\x43MerchantSessionFolderEvent\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08subBizId\x18\x02 \x01(\x05\x12G\n\nsessionRef\x18\x03 \x01(\x0b\x32\x33.AcFunDanmu.Im.Cloud.SessionFolder.SessionReference\x12\x17\n\x0fsessionFolderId\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\x12\x12\n\nupdateTime\x18\x06 \x01(\x03\x12\x12\n\ncreateTime\x18\x07 \x01(\x03\x12\x12\n\nretryCount\x18\x08 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMerchantSessionFolderEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMERCHANTSESSIONFOLDEREVENT._serialized_start=111
  _B2CMERCHANTSESSIONFOLDEREVENT._serialized_end=376
# @@protoc_insertion_point(module_scope)
