syntax = "proto3";

package AcFunDanmu.Im.Message;

import "ChatTargetType.proto";
import "Message.proto";
import "MessageReceiveStatus.proto";
import "RemindBody.proto";
import "SessionStatus.proto";
import "User.proto";

message ChatSession {
	Im.Basic.User target = 1;
	int64 maxSeqId = 2;
	int64 readSeqId = 3;
	int32 unreadMsgCount = 4;
	repeated Message latestMessage = 5;
	ChatTargetType chatTargetType = 8;
	int64 targetId = 9;
	int64 activeTime = 10;
	int32 priority = 11;
	int32 categoryId = 12;
	string cursor = 13;
	int32 accountType = 14;
	bool aggregateSession = 15;
	int32 jumpCategoryId = 16;
	int64 expireAt = 17;
	int64 effectiveFrom = 18;
	string strTargetId = 19;
	repeated RemindBody remindBody = 20;
	int64 targetReadSeqId = 21;
	bool mute = 22;
	SessionStatus status = 23;
	MessageReceiveStatus messageReceiveStatus = 24;
	bytes extra = 25;
	bool markedUnread = 26;
}
