syntax = "proto3";

package AcFunDanmu.Im.Cloud.Message;

enum ImcMessageType {
	TEXT = 0;
	IMAGE = 1;
	CUSTOM = 2;
	AUDIO = 3;
	VIDEO = 4;
	EMOTICON = 5;
	FILE = 6;
	NOTICE = 10;
	RECALLED = 11;
	REFERENCE = 12;
	MERGE_FORWARD = 13;
	MULTI_MEDIA = 14;
	VOICE_CALL = 15;
	PLACE_HOLDER = 100;
	REPLACE = 101;
	DELETE_SYNC = 198;
	INVISIBLE_TYPE_MAX = 199;
	RICH_NOTICE = 200;
	GROUP_INVITATION = 201;
	RED_PACKET = 203;
	CS_EVALUATION = 501;
	CS_QUESTION = 502;
	CS_PICK_QUESTION = 503;
	CS_LIST_CARD = 504;
}
