# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionEventReportRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import EnterSession_pb2 as EnterSession__pb2
import LeaveSession_pb2 as LeaveSession__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fSessionEventReportRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x12\x45nterSession.proto\x1a\x12LeaveSession.proto\"\x9e\x01\n\x19SessionEventReportRequest\x12;\n\x0c\x65nterSession\x18\x01 \x01(\x0b\x32#.AcFunDanmu.Im.Message.EnterSessionH\x00\x12;\n\x0cleaveSession\x18\x02 \x01(\x0b\x32#.AcFunDanmu.Im.Message.LeaveSessionH\x00\x42\x07\n\x05\x65ventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionEventReportRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONEVENTREPORTREQUEST._serialized_start=99
  _SESSIONEVENTREPORTREQUEST._serialized_end=257
# @@protoc_insertion_point(module_scope)
