# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RemindBody.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10RemindBody.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"\xb3\x02\n\nRemindBody\x12@\n\nremindType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Message.RemindBody.RemindType\x12\r\n\x05seqId\x18\x02 \x01(\x03\x12\x10\n\x08targetId\x18\x03 \x01(\x03\x12\x10\n\x08userName\x18\x04 \x01(\t\x12\x12\n\nstartIndex\x18\x05 \x01(\x05\x12\x0e\n\x06length\x18\x06 \x01(\x05\"\x8b\x01\n\nRemindType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41T_ALL\x10\x01\x12\x0b\n\x07\x41T_USER\x10\x02\x12\x12\n\x0eGROUP_BULLETIN\x10\x03\x12\x13\n\x0fRECEIPT_MESSAGE\x10\x04\x12\x16\n\x12GROUP_JOIN_REQUEST\x10\x05\x12\x16\n\x12USER_MESSAGE_ALERT\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RemindBody_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REMINDBODY._serialized_start=44
  _REMINDBODY._serialized_end=351
  _REMINDBODY_REMINDTYPE._serialized_start=212
  _REMINDBODY_REMINDTYPE._serialized_end=351
# @@protoc_insertion_point(module_scope)
