# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelBasicInfoNotify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChannelBasicInfo_pb2 as ChannelBasicInfo__pb2
import UserActionInfo_pb2 as UserActionInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43hannelBasicInfoNotify.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Channel\x1a\x16\x43hannelBasicInfo.proto\x1a\x14UserActionInfo.proto\"\x9f\x01\n\x16\x43hannelBasicInfoNotify\x12\x43\n\x0euserActionInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Channel.UserActionInfo\x12@\n\tbasicInfo\x18\x02 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Channel.ChannelBasicInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChannelBasicInfoNotify_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANNELBASICINFONOTIFY._serialized_start=108
  _CHANNELBASICINFONOTIFY._serialized_end=267
# @@protoc_insertion_point(module_scope)
