# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FlatMessageSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import MessageSearchResult_pb2 as MessageSearchResult__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x46latMessageSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x19MessageSearchResult.proto\"\x83\x01\n\x19\x46latMessageSearchResponse\x12\x45\n\x0csearchResult\x18\x01 \x03(\x0b\x32/.AcFunDanmu.Im.Cloud.Search.MessageSearchResult\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FlatMessageSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLATMESSAGESEARCHRESPONSE._serialized_start=91
  _FLATMESSAGESEARCHRESPONSE._serialized_end=222
# @@protoc_insertion_point(module_scope)
