# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CSessionListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatSession_pb2 as ChatSession__pb2
import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x42\x32\x43SessionListResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x11\x43hatSession.proto\x1a\x10SyncCookie.proto\"\xf3\x01\n\x16\x42\x32\x43SessionListResponse\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12\x34\n\x08sessions\x18\x02 \x03(\x0b\x32\".AcFunDanmu.Im.Message.ChatSession\x12\x14\n\x0cnotFullFetch\x18\x03 \x01(\x08\x12\x12\n\nserverTime\x18\x04 \x01(\x03\x12\x16\n\x0e\x63learLocalData\x18\x05 \x01(\x08\x12\x12\n\ncategoryId\x18\x06 \x01(\x05\x12\x18\n\x10\x63lientDataStatus\x18\x07 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CSessionListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CSESSIONLISTRESPONSE._serialized_start=93
  _B2CSESSIONLISTRESPONSE._serialized_end=336
# @@protoc_insertion_point(module_scope)
