# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccessPoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x41\x63\x63\x65ssPoint.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xf2\x01\n\x0b\x41\x63\x63\x65ssPoint\x12\x41\n\x0b\x61\x64\x64ressType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.AccessPoint.AddressType\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0c\n\x04ipV4\x18\x03 \x01(\x07\x12\x0c\n\x04ipV6\x18\x04 \x01(\x0c\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\x12\x0c\n\x04quic\x18\x06 \x01(\x07\x12\x0e\n\x06quicV6\x18\x07 \x01(\x0c\"H\n\x0b\x41\x64\x64ressType\x12\t\n\x05kIPV4\x10\x00\x12\t\n\x05kIPV6\x10\x01\x12\x0b\n\x07kDomain\x10\x02\x12\t\n\x05kQuic\x10\x03\x12\x0b\n\x07kQuicV6\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccessPoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINT._serialized_start=43
  _ACCESSPOINT._serialized_end=285
  _ACCESSPOINT_ADDRESSTYPE._serialized_start=213
  _ACCESSPOINT_ADDRESSTYPE._serialized_end=285
# @@protoc_insertion_point(module_scope)
