# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KsImDataUpdateType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18KsImDataUpdateType.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update*\x92\x02\n\x12KsImDataUpdateType\x12\x0b\n\x07INVALID\x10\x00\x12\x15\n\x11GROUP_INFO_UPDATE\x10\x01\x12\x1c\n\x18GROUP_MEMBER_LIST_UPDATE\x10\x02\x12\x11\n\rYOU_BE_KICKED\x10\x03\x12\x16\n\x12MESSAGE_READ_EVENT\x10\x04\x12\x19\n\x15MESSAGE_RECEIPT_EVENT\x10\x05\x12\x12\n\x0eSESSION_UPDATE\x10\x06\x12\x19\n\x15SESSION_FOLDER_UPDATE\x10\x07\x12\x18\n\x14\x46\x41VORITE_LIST_UPDATE\x10\x08\x12\x16\n\x12SESSION_TAG_UPDATE\x10\t\x12\x13\n\x0fMESSAGE_CLICKED\x10\nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KsImDataUpdateType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KSIMDATAUPDATETYPE._serialized_start=62
  _KSIMDATAUPDATETYPE._serialized_end=336
# @@protoc_insertion_point(module_scope)
