syntax = "proto3";

package AcFunDanmu;

message ZtDrawGiftInfo {
	int64 screenWidth = 1;
	int64 screenHeight = 2;
	repeated ZtDrawPoint drawPoint = 3;

	message ZtDrawPoint {
		int64 marginLeft = 1;
		int64 marginTop = 2;
		double scaleRatio = 3;
		bool handup = 4;
		int64 pointWidth = 5;
		int64 pointHeight = 6;
	}
}
