# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMemberSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SetUserAntiDisturbing_pb2 as SetUserAntiDisturbing__pb2
import SetUserNickname_pb2 as SetUserNickname__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fGroupMemberSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1bSetUserAntiDisturbing.proto\x1a\x15SetUserNickname.proto\"\xd1\x01\n\x19GroupMemberSettingRequest\x12\x43\n\x0bsetNickname\x18\x02 \x01(\x0b\x32,.AcFunDanmu.Im.Cloud.Message.SetUserNicknameH\x00\x12O\n\x11setAntiDisturbing\x18\x03 \x01(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.SetUserAntiDisturbingH\x00\x12\x0f\n\x07groupId\x18\x01 \x01(\tB\r\n\x0bUserSettingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMemberSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBERSETTINGREQUEST._serialized_start=117
  _GROUPMEMBERSETTINGREQUEST._serialized_end=326
# @@protoc_insertion_point(module_scope)
