# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalPkEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43ommonStateSignalPkEnd.proto\x12\nAcFunDanmu\"\xc4\x01\n\x16\x43ommonStateSignalPkEnd\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\x35\n\x01\x62\x18\x02 \x01(\x0e\x32*.AcFunDanmu.CommonStateSignalPkEnd.unknown\x12\t\n\x01\x63\x18\x03 \x01(\t\"]\n\x07unknown\x12\x05\n\x01\x64\x10\x00\x12\x05\n\x01\x65\x10\x01\x12\x05\n\x01\x66\x10\x02\x12\x05\n\x01g\x10\x03\x12\x05\n\x01h\x10\x04\x12\x05\n\x01i\x10\x05\x12\x05\n\x01j\x10\x06\x12\x05\n\x01k\x10\x07\x12\x05\n\x01l\x10\x08\x12\x05\n\x01m\x10\t\x12\x05\n\x01n\x10\n\x12\x05\n\x01o\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalPkEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALPKEND._serialized_start=45
  _COMMONSTATESIGNALPKEND._serialized_end=241
  _COMMONSTATESIGNALPKEND_UNKNOWN._serialized_start=148
  _COMMONSTATESIGNALPKEND_UNKNOWN._serialized_end=241
# @@protoc_insertion_point(module_scope)
