syntax = "proto3";

package AcFunDanmu.Im.Basic;

message SdkOption {
	int32 reportIntervalSeconds = 1;
	string reportSecurity = 2;
	int32 lz4CompressionThresholdBytes = 3;
	repeated string netCheckServers = 4;
}
