# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveWidgetProto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveWidgetProto.proto\x12\nAcFunDanmu*\x91\x01\n\x12ZtLiveWidgetProtoA\x12\x17\n\x13ZtLiveWidgetProtoAa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoAb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoAc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoAd\x10\x03\x12\x17\n\x13ZtLiveWidgetProtoAe\x10\x04*\xaa\x01\n\x12ZtLiveWidgetProtoB\x12\x17\n\x13ZtLiveWidgetProtoBa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoBb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoBc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoBd\x10\x03\x12\x17\n\x13ZtLiveWidgetProtoBe\x10\x04\x12\x17\n\x13ZtLiveWidgetProtoBf\x10\x05*x\n\x12ZtLiveWidgetProtoC\x12\x17\n\x13ZtLiveWidgetProtoCa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoCb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoCc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoCd\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveWidgetProto_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEWIDGETPROTOA._serialized_start=40
  _ZTLIVEWIDGETPROTOA._serialized_end=185
  _ZTLIVEWIDGETPROTOB._serialized_start=188
  _ZTLIVEWIDGETPROTOB._serialized_end=358
  _ZTLIVEWIDGETPROTOC._serialized_start=360
  _ZTLIVEWIDGETPROTOC._serialized_end=480
# @@protoc_insertion_point(module_scope)
