# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eUserType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*v\n\x08UserType\x12\r\n\tUT_NORMAL\x10\x00\x12\x0f\n\x0bUT_CUSTOMER\x10\x01\x12\x0f\n\x0bUT_MERCHANT\x10\x02\x12\x10\n\x0cUT_ASSISTANT\x10\x03\x12\x0f\n\x0bUT_OFFICIAL\x10\x04\x12\x16\n\tUT_UNKNOW\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERTYPE._serialized_start=41
  _USERTYPE._serialized_end=159
# @@protoc_insertion_point(module_scope)
