# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalRemoveApplyUser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonNotifySignalRemoveApplyUser.proto\x12\nAcFunDanmu\"\x97\x01\n!CommonNotifySignalRemoveApplyUser\x12\t\n\x01\x61\x18\x01 \x01(\x03\x12@\n\x01\x62\x18\x02 \x01(\x0e\x32\x35.AcFunDanmu.CommonNotifySignalRemoveApplyUser.unknown\"%\n\x07unknown\x12\x05\n\x01\x63\x10\x00\x12\x05\n\x01\x64\x10\x01\x12\x05\n\x01\x65\x10\x02\x12\x05\n\x01\x66\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalRemoveApplyUser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER._serialized_start=56
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER._serialized_end=207
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER_UNKNOWN._serialized_start=170
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER_UNKNOWN._serialized_end=207
# @@protoc_insertion_point(module_scope)
