# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveStartPlaySourceTypeProto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ZtLiveStartPlaySourceTypeProto.proto\x12\nAcFunDanmu*j\n\x1eZtLiveStartPlaySourceTypeProto\x12#\n\x1fZtLiveStartPlaySourceTypeProtoA\x10\x00\x12#\n\x1fZtLiveStartPlaySourceTypeProtoB\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveStartPlaySourceTypeProto_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESTARTPLAYSOURCETYPEPROTO._serialized_start=52
  _ZTLIVESTARTPLAYSOURCETYPEPROTO._serialized_end=158
# @@protoc_insertion_point(module_scope)
