# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CreateVoiceCallRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2
import CallType_pb2 as CallType__pb2
import ChatMode_pb2 as ChatMode__pb2
import ChatTarget_pb2 as ChatTarget__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43reateVoiceCallRequest.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\x1a\x0e\x43\x61llType.proto\x1a\x0e\x43hatMode.proto\x1a\x10\x43hatTarget.proto\x1a\nUser.proto\"\xd3\x02\n\x16\x43reateVoiceCallRequest\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12:\n\x08\x63\x61llType\x18\x02 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallType\x12:\n\x08\x63hatMode\x18\x03 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.ChatMode\x12\r\n\x05\x65xtra\x18\x04 \x01(\x0c\x12<\n\tcallParam\x18\x05 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParam\x12.\n\x0bparticipant\x18\x0b \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\r\n\x05title\x18\x0c \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CreateVoiceCallRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEVOICECALLREQUEST._serialized_start=144
  _CREATEVOICECALLREQUEST._serialized_end=483
# @@protoc_insertion_point(module_scope)
