# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupSearchInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupBasicInfo_pb2 as GroupBasicInfo__pb2
import GroupJoinStatus_pb2 as GroupJoinStatus__pb2
import PublicGroupHit_pb2 as PublicGroupHit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bPublicGroupSearchInfo.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x14GroupBasicInfo.proto\x1a\x15GroupJoinStatus.proto\x1a\x14PublicGroupHit.proto\"\xd8\x01\n\x15PublicGroupSearchInfo\x12\x43\n\x0egroupBasicInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Message.GroupBasicInfo\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.AcFunDanmu.Im.Cloud.Message.GroupJoinStatus\x12<\n\x08groupHit\x18\x03 \x01(\x0b\x32*.AcFunDanmu.Im.Cloud.Search.PublicGroupHitb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupSearchInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPSEARCHINFO._serialized_start=127
  _PUBLICGROUPSEARCHINFO._serialized_end=343
# @@protoc_insertion_point(module_scope)
