# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConfirmJoinIntoGroupNoticeMetaInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import JoinRequestStatus_pb2 as JoinRequestStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ConfirmJoinIntoGroupNoticeMetaInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x17JoinRequestStatus.proto\"\x88\x01\n\"ConfirmJoinIntoGroupNoticeMetaInfo\x12\x11\n\trequestId\x18\x01 \x01(\x03\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..AcFunDanmu.Im.Cloud.Message.JoinRequestStatusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ConfirmJoinIntoGroupNoticeMetaInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONFIRMJOININTOGROUPNOTICEMETAINFO._serialized_start=99
  _CONFIRMJOININTOGROUPNOTICEMETAINFO._serialized_end=235
# @@protoc_insertion_point(module_scope)
