# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalFeatureStateSync.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import LiveFeatureState_pb2 as LiveFeatureState__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonStateSignalFeatureStateSync.proto\x12\nAcFunDanmu\x1a\x16LiveFeatureState.proto\"W\n!CommonStateSignalFeatureStateSync\x12\x32\n\x0c\x66\x65\x61tureState\x18\x01 \x03(\x0b\x32\x1c.AcFunDanmu.LiveFeatureStateb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalFeatureStateSync_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALFEATURESTATESYNC._serialized_start=79
  _COMMONSTATESIGNALFEATURESTATESYNC._serialized_end=166
# @@protoc_insertion_point(module_scope)
