syntax = "proto3";

package AcFunDanmu;

import "ZtLiveUserInfo.proto";
import "PkPlayerRoundStatistic.proto";

message PkPlayerStatistic {
    ZtLiveUserInfo a = 1;
    string b = 2;
    int64 c = 3;
    repeated PkPlayerRoundStatistic d = 4;
    int32 e = 5;
}
