# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatChangeSoundConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2CommonStateSignalAuthorChatChangeSoundConfig.proto\x12\nAcFunDanmu\"\xfa\x01\n,CommonStateSignalAuthorChatChangeSoundConfig\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12m\n\x15soundConfigChangeType\x18\x02 \x01(\x0e\x32N.AcFunDanmu.CommonStateSignalAuthorChatChangeSoundConfig.SoundConfigChangeType\"E\n\x15SoundConfigChangeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nOPEN_SOUND\x10\x01\x12\x0f\n\x0b\x43LOSE_SOUND\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatChangeSoundConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG._serialized_start=67
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG._serialized_end=317
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG_SOUNDCONFIGCHANGETYPE._serialized_start=248
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG_SOUNDCONFIGCHANGETYPE._serialized_end=317
# @@protoc_insertion_point(module_scope)
