# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SharePlatform.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13SharePlatform.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic*\xcb\x02\n\rSharePlatform\x12\x19\n\x15kSharePlatformInvalid\x10\x00\x12\x18\n\x14kSharePlatformWechat\x10\x01\x12\x1f\n\x1bkSharePlatformWechatMoments\x10\x02\x12\x14\n\x10kSharePlatformQQ\x10\x03\x12\x17\n\x13kSharePlatformQzone\x10\x04\x12\x17\n\x13kSharePlatformWeibo\x10\x05\x12\x1a\n\x16kSharePlatformKuaishou\x10\x06\x12\x1a\n\x16kSharePlatformFacebook\x10\x07\x12\x19\n\x15kSharePlatformTwitter\x10\x08\x12\x18\n\x14kSharePlatformGoogle\x10\t\x12\x17\n\x13kSharePlatformKakao\x10\n\x12\x16\n\x12kSharePlatformZalo\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SharePlatform_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHAREPLATFORM._serialized_start=45
  _SHAREPLATFORM._serialized_end=376
# @@protoc_insertion_point(module_scope)
