# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalUserShareLive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%CommonActionSignalUserShareLive.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xb0\x01\n\x1f\x43ommonActionSignalUserShareLive\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x17\n\x0fsharePlatformId\x18\x02 \x01(\x05\x12\x19\n\x11sharePlatformIcon\x18\x03 \x01(\t\x12\x12\n\nsendTimeMs\x18\x04 \x01(\x03\"\x17\n\x07unknown\x12\x05\n\x01\x65\x10\x00\x12\x05\n\x01\x66\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalUserShareLive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALUSERSHARELIVE._serialized_start=76
  _COMMONACTIONSIGNALUSERSHARELIVE._serialized_end=252
  _COMMONACTIONSIGNALUSERSHARELIVE_UNKNOWN._serialized_start=229
  _COMMONACTIONSIGNALUSERSHARELIVE_UNKNOWN._serialized_end=252
# @@protoc_insertion_point(module_scope)
