# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcMessageType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ImcMessageType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\x90\x03\n\x0eImcMessageType\x12\x08\n\x04TEXT\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\t\n\x05\x41UDIO\x10\x03\x12\t\n\x05VIDEO\x10\x04\x12\x0c\n\x08\x45MOTICON\x10\x05\x12\x08\n\x04\x46ILE\x10\x06\x12\n\n\x06NOTICE\x10\n\x12\x0c\n\x08RECALLED\x10\x0b\x12\r\n\tREFERENCE\x10\x0c\x12\x11\n\rMERGE_FORWARD\x10\r\x12\x0f\n\x0bMULTI_MEDIA\x10\x0e\x12\x0e\n\nVOICE_CALL\x10\x0f\x12\x10\n\x0cPLACE_HOLDER\x10\x64\x12\x0b\n\x07REPLACE\x10\x65\x12\x10\n\x0b\x44\x45LETE_SYNC\x10\xc6\x01\x12\x17\n\x12INVISIBLE_TYPE_MAX\x10\xc7\x01\x12\x10\n\x0bRICH_NOTICE\x10\xc8\x01\x12\x15\n\x10GROUP_INVITATION\x10\xc9\x01\x12\x0f\n\nRED_PACKET\x10\xcb\x01\x12\x12\n\rCS_EVALUATION\x10\xf5\x03\x12\x10\n\x0b\x43S_QUESTION\x10\xf6\x03\x12\x15\n\x10\x43S_PICK_QUESTION\x10\xf7\x03\x12\x11\n\x0c\x43S_LIST_CARD\x10\xf8\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcMessageType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCMESSAGETYPE._serialized_start=54
  _IMCMESSAGETYPE._serialized_end=454
# @@protoc_insertion_point(module_scope)
